Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesRequestLocationBias
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesRequestLocationBias
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
The region to search. The results may be biased around the specified region.
Instance Attribute Summary collapse
-
#circle ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1Circle
Circle with a LatLng as center and radius.
-
#rectangle ⇒ Google::Apis::PlacesV1::GoogleGeoTypeViewport
A latitude-longitude viewport, represented as two diagonally opposite
lowandhighpoints.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1AutocompletePlacesRequestLocationBias
constructor
A new instance of GoogleMapsPlacesV1AutocompletePlacesRequestLocationBias.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1AutocompletePlacesRequestLocationBias
Returns a new instance of GoogleMapsPlacesV1AutocompletePlacesRequestLocationBias.
401 402 403 |
# File 'lib/google/apis/places_v1/classes.rb', line 401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#circle ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1Circle
Circle with a LatLng as center and radius.
Corresponds to the JSON property circle
379 380 381 |
# File 'lib/google/apis/places_v1/classes.rb', line 379 def circle @circle end |
#rectangle ⇒ Google::Apis::PlacesV1::GoogleGeoTypeViewport
A latitude-longitude viewport, represented as two diagonally opposite low
and high points. A viewport is considered a closed region, i.e. it includes
its boundary. The latitude bounds must range between -90 to 90 degrees
inclusive, and the longitude bounds must range between -180 to 180 degrees
inclusive. Various cases include: - If low = high, the viewport consists
of that single point. - If low.longitude > high.longitude, the longitude
range is inverted (the viewport crosses the 180 degree longitude line). - If
low.longitude = -180 degrees and high.longitude = 180 degrees, the viewport
includes all longitudes. - If low.longitude = 180 degrees and high.
longitude = -180 degrees, the longitude range is empty. - If low.latitude >
high.latitude, the latitude range is empty. Both low and high must be
populated, and the represented box cannot be empty (as specified by the
definitions above). An empty viewport will result in an error. For example,
this viewport fully encloses New York City: "low": "latitude": 40.477398, "
longitude": -74.259087 , "high": "latitude": 40.91618, "longitude": -73.
70018
Corresponds to the JSON property rectangle
399 400 401 |
# File 'lib/google/apis/places_v1/classes.rb', line 399 def rectangle @rectangle end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
406 407 408 409 |
# File 'lib/google/apis/places_v1/classes.rb', line 406 def update!(**args) @circle = args[:circle] if args.key?(:circle) @rectangle = args[:rectangle] if args.key?(:rectangle) end |