Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Text representing a Place or query prediction. The text may be used as is or formatted.
Instance Attribute Summary collapse
-
#matches ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStringRange>
A list of string ranges identifying where the input request matched in
text. -
#text ⇒ String
Text that may be used as is or formatted with
matches.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText
constructor
A new instance of GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText
Returns a new instance of GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText.
516 517 518 |
# File 'lib/google/apis/places_v1/classes.rb', line 516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#matches ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStringRange>
A list of string ranges identifying where the input request matched in text.
The ranges can be used to format specific parts of text. The substrings may
not be exact matches of input if the matching was determined by criteria
other than string matching (for example, spell corrections or transliterations)
. These values are Unicode character offsets of text. The ranges are
guaranteed to be ordered in increasing offset values.
Corresponds to the JSON property matches
509 510 511 |
# File 'lib/google/apis/places_v1/classes.rb', line 509 def matches @matches end |
#text ⇒ String
Text that may be used as is or formatted with matches.
Corresponds to the JSON property text
514 515 516 |
# File 'lib/google/apis/places_v1/classes.rb', line 514 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
521 522 523 524 |
# File 'lib/google/apis/places_v1/classes.rb', line 521 def update!(**args) @matches = args[:matches] if args.key?(:matches) @text = args[:text] if args.key?(:text) end |