Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionQueryPrediction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Prediction results for a Query Autocomplete prediction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionQueryPrediction

Returns a new instance of GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionQueryPrediction.



606
607
608
# File 'lib/google/apis/places_v1/classes.rb', line 606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#structured_formatGoogle::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionStructuredFormat

Contains a breakdown of a Place or query prediction into main text and secondary text. For Place predictions, the main text contains the specific name of the Place. For query predictions, the main text contains the query. The secondary text contains additional disambiguating features (such as a city or region) to further identify the Place or refine the query. Corresponds to the JSON property structuredFormat



598
599
600
# File 'lib/google/apis/places_v1/classes.rb', line 598

def structured_format
  @structured_format
end

#textGoogle::Apis::PlacesV1::GoogleMapsPlacesV1AutocompletePlacesResponseSuggestionFormattableText

Text representing a Place or query prediction. The text may be used as is or formatted. Corresponds to the JSON property text



604
605
606
# File 'lib/google/apis/places_v1/classes.rb', line 604

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



611
612
613
614
# File 'lib/google/apis/places_v1/classes.rb', line 611

def update!(**args)
  @structured_format = args[:structured_format] if args.key?(:structured_format)
  @text = args[:text] if args.key?(:text)
end