Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1Circle

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Circle with a LatLng as center and radius.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1Circle

Returns a new instance of GoogleMapsPlacesV1Circle.



690
691
692
# File 'lib/google/apis/places_v1/classes.rb', line 690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#centerGoogle::Apis::PlacesV1::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property center



683
684
685
# File 'lib/google/apis/places_v1/classes.rb', line 683

def center
  @center
end

#radiusFloat

Required. Radius measured in meters. The radius must be within [0.0, 50000.0]. Corresponds to the JSON property radius

Returns:

  • (Float)


688
689
690
# File 'lib/google/apis/places_v1/classes.rb', line 688

def radius
  @radius
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



695
696
697
698
# File 'lib/google/apis/places_v1/classes.rb', line 695

def update!(**args)
  @center = args[:center] if args.key?(:center)
  @radius = args[:radius] if args.key?(:radius)
end