Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

A block of content that can be served individually.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1ContentBlock

Returns a new instance of GoogleMapsPlacesV1ContentBlock.



716
717
718
# File 'lib/google/apis/places_v1/classes.rb', line 716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property content



708
709
710
# File 'lib/google/apis/places_v1/classes.rb', line 708

def content
  @content
end

#referenced_placesArray<String>

The list of resource names of the referenced places. This name can be used in other APIs that accept Place resource names. Corresponds to the JSON property referencedPlaces

Returns:

  • (Array<String>)


714
715
716
# File 'lib/google/apis/places_v1/classes.rb', line 714

def referenced_places
  @referenced_places
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



721
722
723
724
# File 'lib/google/apis/places_v1/classes.rb', line 721

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @referenced_places = args[:referenced_places] if args.key?(:referenced_places)
end