Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Justifications for the place. Justifications answers the question of why a place could interest an end user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1ContextualContentJustification

Returns a new instance of GoogleMapsPlacesV1ContextualContentJustification.



778
779
780
# File 'lib/google/apis/places_v1/classes.rb', line 778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_availability_attributes_justificationGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustificationBusinessAvailabilityAttributesJustification

BusinessAvailabilityAttributes justifications. This shows some attributes a business has that could interest an end user. Corresponds to the JSON property businessAvailabilityAttributesJustification



768
769
770
# File 'lib/google/apis/places_v1/classes.rb', line 768

def business_availability_attributes_justification
  @business_availability_attributes_justification
end

#review_justificationGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustificationReviewJustification

User review justifications. This highlights a section of the user review that would interest an end user. For instance, if the search query is "firewood pizza", the review justification highlights the text relevant to the search query. Corresponds to the JSON property reviewJustification



776
777
778
# File 'lib/google/apis/places_v1/classes.rb', line 776

def review_justification
  @review_justification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



783
784
785
786
# File 'lib/google/apis/places_v1/classes.rb', line 783

def update!(**args)
  @business_availability_attributes_justification = args[:business_availability_attributes_justification] if args.key?(:business_availability_attributes_justification)
  @review_justification = args[:review_justification] if args.key?(:review_justification)
end