Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustificationReviewJustification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

User review justifications. This highlights a section of the user review that would interest an end user. For instance, if the search query is "firewood pizza", the review justification highlights the text relevant to the search query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1ContextualContentJustificationReviewJustification

Returns a new instance of GoogleMapsPlacesV1ContextualContentJustificationReviewJustification.



843
844
845
# File 'lib/google/apis/places_v1/classes.rb', line 843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#highlighted_textGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedText

The text highlighted by the justification. This is a subset of the review itself. The exact word to highlight is marked by the HighlightedTextRange. There could be several words in the text being highlighted. Corresponds to the JSON property highlightedText



836
837
838
# File 'lib/google/apis/places_v1/classes.rb', line 836

def highlighted_text
  @highlighted_text
end

#reviewGoogle::Apis::PlacesV1::GoogleMapsPlacesV1Review

Information about a review of a place. Corresponds to the JSON property review



841
842
843
# File 'lib/google/apis/places_v1/classes.rb', line 841

def review
  @review
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



848
849
850
851
# File 'lib/google/apis/places_v1/classes.rb', line 848

def update!(**args)
  @highlighted_text = args[:highlighted_text] if args.key?(:highlighted_text)
  @review = args[:review] if args.key?(:review)
end