Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedText

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

The text highlighted by the justification. This is a subset of the review itself. The exact word to highlight is marked by the HighlightedTextRange. There could be several words in the text being highlighted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedText

Returns a new instance of GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedText.



870
871
872
# File 'lib/google/apis/places_v1/classes.rb', line 870

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#highlighted_text_rangesArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustificationReviewJustificationHighlightedTextHighlightedTextRange>

The list of the ranges of the highlighted text. Corresponds to the JSON property highlightedTextRanges



863
864
865
# File 'lib/google/apis/places_v1/classes.rb', line 863

def highlighted_text_ranges
  @highlighted_text_ranges
end

#textString

Corresponds to the JSON property text

Returns:

  • (String)


868
869
870
# File 'lib/google/apis/places_v1/classes.rb', line 868

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



875
876
877
878
# File 'lib/google/apis/places_v1/classes.rb', line 875

def update!(**args)
  @highlighted_text_ranges = args[:highlighted_text_ranges] if args.key?(:highlighted_text_ranges)
  @text = args[:text] if args.key?(:text)
end