Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1EvChargeOptionsConnectorAggregation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

EV charging information grouped by [type, max_charge_rate_kw]. Shows EV charge aggregation of connectors that have the same type and max charge rate in kw.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1EvChargeOptionsConnectorAggregation

Returns a new instance of GoogleMapsPlacesV1EvChargeOptionsConnectorAggregation.



974
975
976
# File 'lib/google/apis/places_v1/classes.rb', line 974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_last_update_timeString

The timestamp when the connector availability information in this aggregation was last updated. Corresponds to the JSON property availabilityLastUpdateTime

Returns:

  • (String)


947
948
949
# File 'lib/google/apis/places_v1/classes.rb', line 947

def availability_last_update_time
  @availability_last_update_time
end

#available_countFixnum

Number of connectors in this aggregation that are currently available. Corresponds to the JSON property availableCount

Returns:

  • (Fixnum)


952
953
954
# File 'lib/google/apis/places_v1/classes.rb', line 952

def available_count
  @available_count
end

#countFixnum

Number of connectors in this aggregation. Corresponds to the JSON property count

Returns:

  • (Fixnum)


957
958
959
# File 'lib/google/apis/places_v1/classes.rb', line 957

def count
  @count
end

#max_charge_rate_kwFloat

The static max charging rate in kw of each connector in the aggregation. Corresponds to the JSON property maxChargeRateKw

Returns:

  • (Float)


962
963
964
# File 'lib/google/apis/places_v1/classes.rb', line 962

def max_charge_rate_kw
  @max_charge_rate_kw
end

#out_of_service_countFixnum

Number of connectors in this aggregation that are currently out of service. Corresponds to the JSON property outOfServiceCount

Returns:

  • (Fixnum)


967
968
969
# File 'lib/google/apis/places_v1/classes.rb', line 967

def out_of_service_count
  @out_of_service_count
end

#typeString

The connector type of this aggregation. Corresponds to the JSON property type

Returns:

  • (String)


972
973
974
# File 'lib/google/apis/places_v1/classes.rb', line 972

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



979
980
981
982
983
984
985
986
# File 'lib/google/apis/places_v1/classes.rb', line 979

def update!(**args)
  @availability_last_update_time = args[:availability_last_update_time] if args.key?(:availability_last_update_time)
  @available_count = args[:available_count] if args.key?(:available_count)
  @count = args[:count] if args.key?(:count)
  @max_charge_rate_kw = args[:max_charge_rate_kw] if args.key?(:max_charge_rate_kw)
  @out_of_service_count = args[:out_of_service_count] if args.key?(:out_of_service_count)
  @type = args[:type] if args.key?(:type)
end