Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1FuelOptions
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1FuelOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
The most recent information about fuel options in a gas station. This information is updated regularly.
Instance Attribute Summary collapse
-
#fuel_prices ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1FuelOptionsFuelPrice>
The last known fuel price for each type of fuel this station has.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1FuelOptions
constructor
A new instance of GoogleMapsPlacesV1FuelOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1FuelOptions
Returns a new instance of GoogleMapsPlacesV1FuelOptions.
1000 1001 1002 |
# File 'lib/google/apis/places_v1/classes.rb', line 1000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fuel_prices ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1FuelOptionsFuelPrice>
The last known fuel price for each type of fuel this station has. There is one
entry per fuel type this station has. Order is not important.
Corresponds to the JSON property fuelPrices
998 999 1000 |
# File 'lib/google/apis/places_v1/classes.rb', line 998 def fuel_prices @fuel_prices end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1005 1006 1007 |
# File 'lib/google/apis/places_v1/classes.rb', line 1005 def update!(**args) @fuel_prices = args[:fuel_prices] if args.key?(:fuel_prices) end |