Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1Photo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Information about a photo of a place.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1Photo

Returns a new instance of GoogleMapsPlacesV1Photo.



1089
1090
1091
# File 'lib/google/apis/places_v1/classes.rb', line 1089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#author_attributionsArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1AuthorAttribution>

This photo's authors. Corresponds to the JSON property authorAttributions



1060
1061
1062
# File 'lib/google/apis/places_v1/classes.rb', line 1060

def author_attributions
  @author_attributions
end

#flag_content_uriString

A link where users can flag a problem with the photo. Corresponds to the JSON property flagContentUri

Returns:

  • (String)


1065
1066
1067
# File 'lib/google/apis/places_v1/classes.rb', line 1065

def flag_content_uri
  @flag_content_uri
end

#google_maps_uriString

A link to show the photo on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


1070
1071
1072
# File 'lib/google/apis/places_v1/classes.rb', line 1070

def google_maps_uri
  @google_maps_uri
end

#height_pxFixnum

The maximum available height, in pixels. Corresponds to the JSON property heightPx

Returns:

  • (Fixnum)


1075
1076
1077
# File 'lib/google/apis/places_v1/classes.rb', line 1075

def height_px
  @height_px
end

#nameString

Identifier. A reference representing this place photo which may be used to look up this place photo again (also called the API "resource" name: places/ place_id/photos/photo`). Corresponds to the JSON propertyname`

Returns:

  • (String)


1082
1083
1084
# File 'lib/google/apis/places_v1/classes.rb', line 1082

def name
  @name
end

#width_pxFixnum

The maximum available width, in pixels. Corresponds to the JSON property widthPx

Returns:

  • (Fixnum)


1087
1088
1089
# File 'lib/google/apis/places_v1/classes.rb', line 1087

def width_px
  @width_px
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1094
1095
1096
1097
1098
1099
1100
1101
# File 'lib/google/apis/places_v1/classes.rb', line 1094

def update!(**args)
  @author_attributions = args[:author_attributions] if args.key?(:author_attributions)
  @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @height_px = args[:height_px] if args.key?(:height_px)
  @name = args[:name] if args.key?(:name)
  @width_px = args[:width_px] if args.key?(:width_px)
end