Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAddressComponent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

The structured components that form the formatted address, if this information is available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceAddressComponent

Returns a new instance of GoogleMapsPlacesV1PlaceAddressComponent.



1803
1804
1805
# File 'lib/google/apis/places_v1/classes.rb', line 1803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_codeString

The language used to format this components, in CLDR notation. Corresponds to the JSON property languageCode

Returns:

  • (String)


1782
1783
1784
# File 'lib/google/apis/places_v1/classes.rb', line 1782

def language_code
  @language_code
end

#long_textString

The full text description or name of the address component. For example, an address component for the country Australia may have a long_name of "Australia" . Corresponds to the JSON property longText

Returns:

  • (String)


1789
1790
1791
# File 'lib/google/apis/places_v1/classes.rb', line 1789

def long_text
  @long_text
end

#short_textString

An abbreviated textual name for the address component, if available. For example, an address component for the country of Australia may have a short_name of "AU". Corresponds to the JSON property shortText

Returns:

  • (String)


1796
1797
1798
# File 'lib/google/apis/places_v1/classes.rb', line 1796

def short_text
  @short_text
end

#typesArray<String>

An array indicating the type(s) of the address component. Corresponds to the JSON property types

Returns:

  • (Array<String>)


1801
1802
1803
# File 'lib/google/apis/places_v1/classes.rb', line 1801

def types
  @types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1808
1809
1810
1811
1812
1813
# File 'lib/google/apis/places_v1/classes.rb', line 1808

def update!(**args)
  @language_code = args[:language_code] if args.key?(:language_code)
  @long_text = args[:long_text] if args.key?(:long_text)
  @short_text = args[:short_text] if args.key?(:short_text)
  @types = args[:types] if args.key?(:types)
end