Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlert

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

The consumer alert message for the place when we detect suspicious review activity on a business or a business violates our policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceConsumerAlert

Returns a new instance of GoogleMapsPlacesV1PlaceConsumerAlert.



1856
1857
1858
# File 'lib/google/apis/places_v1/classes.rb', line 1856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlertDetails

The details of the consumer alert message. Corresponds to the JSON property details



1843
1844
1845
# File 'lib/google/apis/places_v1/classes.rb', line 1843

def details
  @details
end

#language_codeString

The language code of the consumer alert message. This is a BCP 47 language code. Corresponds to the JSON property languageCode

Returns:

  • (String)


1849
1850
1851
# File 'lib/google/apis/places_v1/classes.rb', line 1849

def language_code
  @language_code
end

#overviewString

The overview of the consumer alert message. Corresponds to the JSON property overview

Returns:

  • (String)


1854
1855
1856
# File 'lib/google/apis/places_v1/classes.rb', line 1854

def overview
  @overview
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1861
1862
1863
1864
1865
# File 'lib/google/apis/places_v1/classes.rb', line 1861

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @language_code = args[:language_code] if args.key?(:language_code)
  @overview = args[:overview] if args.key?(:overview)
end