Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceEntrance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

An entrance is a single latitude/longitude coordinate pair that defines the location of an entry and exit point for a place.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceEntrance

Returns a new instance of GoogleMapsPlacesV1PlaceEntrance.



1973
1974
1975
# File 'lib/google/apis/places_v1/classes.rb', line 1973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationGoogle::Apis::PlacesV1::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property location



1966
1967
1968
# File 'lib/google/apis/places_v1/classes.rb', line 1966

def location
  @location
end

#tagsArray<String>

A list of tags that describe the entrance. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


1971
1972
1973
# File 'lib/google/apis/places_v1/classes.rb', line 1971

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1978
1979
1980
1981
# File 'lib/google/apis/places_v1/classes.rb', line 1978

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @tags = args[:tags] if args.key?(:tags)
end