Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGoogleMapsLinks

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Links to trigger different Google Maps actions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceGoogleMapsLinks

Returns a new instance of GoogleMapsPlacesV1PlaceGoogleMapsLinks.



2096
2097
2098
# File 'lib/google/apis/places_v1/classes.rb', line 2096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#directions_uriString

A link to show the directions to the place. The link only populates the destination location and uses the default travel mode DRIVE. Corresponds to the JSON property directionsUri

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/places_v1/classes.rb', line 2074

def directions_uri
  @directions_uri
end

#photos_uriString

A link to show photos of this place on Google Maps. Corresponds to the JSON property photosUri

Returns:

  • (String)


2079
2080
2081
# File 'lib/google/apis/places_v1/classes.rb', line 2079

def photos_uri
  @photos_uri
end

#place_uriString

A link to show this place. Corresponds to the JSON property placeUri

Returns:

  • (String)


2084
2085
2086
# File 'lib/google/apis/places_v1/classes.rb', line 2084

def place_uri
  @place_uri
end

#reviews_uriString

A link to show reviews of this place on Google Maps. Corresponds to the JSON property reviewsUri

Returns:

  • (String)


2089
2090
2091
# File 'lib/google/apis/places_v1/classes.rb', line 2089

def reviews_uri
  @reviews_uri
end

#write_a_review_uriString

A link to write a review for this place on Google Maps. Corresponds to the JSON property writeAReviewUri

Returns:

  • (String)


2094
2095
2096
# File 'lib/google/apis/places_v1/classes.rb', line 2094

def write_a_review_uri
  @write_a_review_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2101
2102
2103
2104
2105
2106
2107
# File 'lib/google/apis/places_v1/classes.rb', line 2101

def update!(**args)
  @directions_uri = args[:directions_uri] if args.key?(:directions_uri)
  @photos_uri = args[:photos_uri] if args.key?(:photos_uri)
  @place_uri = args[:place_uri] if args.key?(:place_uri)
  @reviews_uri = args[:reviews_uri] if args.key?(:reviews_uri)
  @write_a_review_uri = args[:write_a_review_uri] if args.key?(:write_a_review_uri)
end