Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceNavigationPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

A navigation point is a location next to a road where navigation can end.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceNavigationPoint

Returns a new instance of GoogleMapsPlacesV1PlaceNavigationPoint.



2144
2145
2146
# File 'lib/google/apis/places_v1/classes.rb', line 2144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property displayName



2117
2118
2119
# File 'lib/google/apis/places_v1/classes.rb', line 2117

def display_name
  @display_name
end

#locationGoogle::Apis::PlacesV1::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property location



2125
2126
2127
# File 'lib/google/apis/places_v1/classes.rb', line 2125

def location
  @location
end

A token that can be used to identify this navigation point. Corresponds to the JSON property navigationPointToken

Returns:

  • (String)


2130
2131
2132
# File 'lib/google/apis/places_v1/classes.rb', line 2130

def navigation_point_token
  @navigation_point_token
end

#travel_modesArray<String>

Travel modes that are appropriate for this navigation point. Corresponds to the JSON property travelModes

Returns:

  • (Array<String>)


2135
2136
2137
# File 'lib/google/apis/places_v1/classes.rb', line 2135

def travel_modes
  @travel_modes
end

#usagesArray<String>

Lists usages supported by this navigation point. If empty, it does not necessarily mean its usage is restricted in any way. All navigation points can be used for general navigation. Corresponds to the JSON property usages

Returns:

  • (Array<String>)


2142
2143
2144
# File 'lib/google/apis/places_v1/classes.rb', line 2142

def usages
  @usages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2149
2150
2151
2152
2153
2154
2155
# File 'lib/google/apis/places_v1/classes.rb', line 2149

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @location = args[:location] if args.key?(:location)
  @navigation_point_token = args[:navigation_point_token] if args.key?(:navigation_point_token)
  @travel_modes = args[:travel_modes] if args.key?(:travel_modes)
  @usages = args[:usages] if args.key?(:usages)
end