Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1Polyline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

A route polyline. Only supports an encoded polyline, which can be passed as a string and includes compression with minimal lossiness. This is the Routes API default output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1Polyline

Returns a new instance of GoogleMapsPlacesV1Polyline.



2604
2605
2606
# File 'lib/google/apis/places_v1/classes.rb', line 2604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encoded_polylineString

An encoded polyline, as returned by the Routes API by default. See the encoder and decoder tools. Corresponds to the JSON property encodedPolyline

Returns:

  • (String)


2602
2603
2604
# File 'lib/google/apis/places_v1/classes.rb', line 2602

def encoded_polyline
  @encoded_polyline
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2609
2610
2611
# File 'lib/google/apis/places_v1/classes.rb', line 2609

def update!(**args)
  @encoded_polyline = args[:encoded_polyline] if args.key?(:encoded_polyline)
end