Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PriceRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

The price range associated with a Place. end_price could be unset, which indicates a range without upper bound (e.g. "More than $100").

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PriceRange

Returns a new instance of GoogleMapsPlacesV1PriceRange.



2629
2630
2631
# File 'lib/google/apis/places_v1/classes.rb', line 2629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_priceGoogle::Apis::PlacesV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property endPrice



2622
2623
2624
# File 'lib/google/apis/places_v1/classes.rb', line 2622

def end_price
  @end_price
end

#start_priceGoogle::Apis::PlacesV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property startPrice



2627
2628
2629
# File 'lib/google/apis/places_v1/classes.rb', line 2627

def start_price
  @start_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2634
2635
2636
2637
# File 'lib/google/apis/places_v1/classes.rb', line 2634

def update!(**args)
  @end_price = args[:end_price] if args.key?(:end_price)
  @start_price = args[:start_price] if args.key?(:start_price)
end