Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchNearbyRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Request proto for Search Nearby.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1SearchNearbyRequest

Returns a new instance of GoogleMapsPlacesV1SearchNearbyRequest.



3001
3002
3003
# File 'lib/google/apis/places_v1/classes.rb', line 3001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_primary_typesArray<String>

Excluded primary Place type (e.g. "restaurant" or "gas_station") from https:// developers.google.com/maps/documentation/places/web-service/place-types. Up to 50 types from Table A may be specified. If there are any conflicting primary types, i.e. a type appears in both included_primary_types and excluded_primary_types, an INVALID_ARGUMENT error is returned. If a Place type is specified with multiple type restrictions, only places that satisfy all of the restrictions are returned. For example, if we have included_types = ["restaurant"], excluded_primary_types = ["restaurant"], the returned places provide "restaurant" related services but do not operate primarily as " restaurants". Corresponds to the JSON property excludedPrimaryTypes

Returns:

  • (Array<String>)


2899
2900
2901
# File 'lib/google/apis/places_v1/classes.rb', line 2899

def excluded_primary_types
  @excluded_primary_types
end

#excluded_typesArray<String>

Excluded Place type (eg, "restaurant" or "gas_station") from https:// developers.google.com/maps/documentation/places/web-service/place-types. Up to 50 types from Table A may be specified. If the client provides both included_types (e.g. restaurant) and excluded_types (e.g. cafe), then the response should include places that are restaurant but not cafe. The response includes places that match at least one of the included_types and none of the excluded_types. If there are any conflicting types, i.e. a type appears in both included_types and excluded_types, an INVALID_ARGUMENT error is returned. If a Place type is specified with multiple type restrictions, only places that satisfy all of the restrictions are returned. For example, if we have included_types = ["restaurant"], excluded_primary_types = [" restaurant"], the returned places provide "restaurant" related services but do not operate primarily as "restaurants". Corresponds to the JSON property excludedTypes

Returns:

  • (Array<String>)


2917
2918
2919
# File 'lib/google/apis/places_v1/classes.rb', line 2917

def excluded_types
  @excluded_types
end

#include_future_opening_businessesBoolean Also known as: include_future_opening_businesses?

Optional. If true, include businesses that are not yet open but will open in the future. Corresponds to the JSON property includeFutureOpeningBusinesses

Returns:

  • (Boolean)


2923
2924
2925
# File 'lib/google/apis/places_v1/classes.rb', line 2923

def include_future_opening_businesses
  @include_future_opening_businesses
end

#included_primary_typesArray<String>

Included primary Place type (e.g. "restaurant" or "gas_station") from https:// developers.google.com/maps/documentation/places/web-service/place-types. A place can only have a single primary type from the supported types table associated with it. Up to 50 types from Table A may be specified. If there are any conflicting primary types, i.e. a type appears in both included_primary_types and excluded_primary_types, an INVALID_ARGUMENT error is returned. If a Place type is specified with multiple type restrictions, only places that satisfy all of the restrictions are returned. For example, if we have included_types = ["restaurant"], excluded_primary_types = ["restaurant"], the returned places provide " restaurant" related services but do not operate primarily as "restaurants". Corresponds to the JSON property includedPrimaryTypes

Returns:

  • (Array<String>)


2940
2941
2942
# File 'lib/google/apis/places_v1/classes.rb', line 2940

def included_primary_types
  @included_primary_types
end

#included_typesArray<String>

Included Place type (eg, "restaurant" or "gas_station") from https:// developers.google.com/maps/documentation/places/web-service/place-types. Up to 50 types from Table A may be specified. If there are any conflicting types, i.e. a type appears in both included_types and excluded_types, an INVALID_ARGUMENT error is returned. If a Place type is specified with multiple type restrictions, only places that satisfy all of the restrictions are returned. For example, if we have included_types = [" restaurant"], excluded_primary_types = ["restaurant"], the returned places provide "restaurant" related services but do not operate primarily as " restaurants". Corresponds to the JSON property includedTypes

Returns:

  • (Array<String>)


2955
2956
2957
# File 'lib/google/apis/places_v1/classes.rb', line 2955

def included_types
  @included_types
end

#language_codeString

Place details will be displayed with the preferred language if available. If the language code is unspecified or unrecognized, place details of any language may be returned, with a preference for English if such details exist. Current list of supported languages: https://developers.google.com/maps/faq# languagesupport. Corresponds to the JSON property languageCode

Returns:

  • (String)


2964
2965
2966
# File 'lib/google/apis/places_v1/classes.rb', line 2964

def language_code
  @language_code
end

#location_restrictionGoogle::Apis::PlacesV1::GoogleMapsPlacesV1SearchNearbyRequestLocationRestriction

The region to search. Corresponds to the JSON property locationRestriction



2969
2970
2971
# File 'lib/google/apis/places_v1/classes.rb', line 2969

def location_restriction
  @location_restriction
end

#max_result_countFixnum

Maximum number of results to return. It must be between 1 and 20 (default), inclusively. If the number is unset, it falls back to the upper limit. If the number is set to negative or exceeds the upper limit, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property maxResultCount

Returns:

  • (Fixnum)


2977
2978
2979
# File 'lib/google/apis/places_v1/classes.rb', line 2977

def max_result_count
  @max_result_count
end

#rank_preferenceString

How results will be ranked in the response. Corresponds to the JSON property rankPreference

Returns:

  • (String)


2982
2983
2984
# File 'lib/google/apis/places_v1/classes.rb', line 2982

def rank_preference
  @rank_preference
end

#region_codeString

The Unicode country/region code (CLDR) of the location where the request is coming from. This parameter is used to display the place details, like region- specific place name, if available. The parameter can affect results based on applicable law. For more information, see https://www.unicode.org/cldr/charts/ latest/supplemental/territory_language_information.html. Note that 3-digit region codes are not currently supported. Corresponds to the JSON property regionCode

Returns:

  • (String)


2992
2993
2994
# File 'lib/google/apis/places_v1/classes.rb', line 2992

def region_code
  @region_code
end

#routing_parametersGoogle::Apis::PlacesV1::GoogleMapsPlacesV1RoutingParameters

Parameters to configure the routing calculations to the places in the response, both along a route (where result ranking will be influenced) and for calculating travel times on results. Corresponds to the JSON property routingParameters



2999
3000
3001
# File 'lib/google/apis/places_v1/classes.rb', line 2999

def routing_parameters
  @routing_parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
# File 'lib/google/apis/places_v1/classes.rb', line 3006

def update!(**args)
  @excluded_primary_types = args[:excluded_primary_types] if args.key?(:excluded_primary_types)
  @excluded_types = args[:excluded_types] if args.key?(:excluded_types)
  @include_future_opening_businesses = args[:include_future_opening_businesses] if args.key?(:include_future_opening_businesses)
  @included_primary_types = args[:included_primary_types] if args.key?(:included_primary_types)
  @included_types = args[:included_types] if args.key?(:included_types)
  @language_code = args[:language_code] if args.key?(:language_code)
  @location_restriction = args[:location_restriction] if args.key?(:location_restriction)
  @max_result_count = args[:max_result_count] if args.key?(:max_result_count)
  @rank_preference = args[:rank_preference] if args.key?(:rank_preference)
  @region_code = args[:region_code] if args.key?(:region_code)
  @routing_parameters = args[:routing_parameters] if args.key?(:routing_parameters)
end