Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextRequestEvOptions
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextRequestEvOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Searchable EV options of a place search request.
Instance Attribute Summary collapse
-
#connector_types ⇒ Array<String>
Optional.
-
#minimum_charging_rate_kw ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextRequestEvOptions
constructor
A new instance of GoogleMapsPlacesV1SearchTextRequestEvOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextRequestEvOptions
Returns a new instance of GoogleMapsPlacesV1SearchTextRequestEvOptions.
3190 3191 3192 |
# File 'lib/google/apis/places_v1/classes.rb', line 3190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connector_types ⇒ Array<String>
Optional. The list of preferred EV connector types. A place that does not
support any of the listed connector types is filtered out.
Corresponds to the JSON property connectorTypes
3182 3183 3184 |
# File 'lib/google/apis/places_v1/classes.rb', line 3182 def connector_types @connector_types end |
#minimum_charging_rate_kw ⇒ Float
Optional. Minimum required charging rate in kilowatts. A place with a charging
rate less than the specified rate is filtered out.
Corresponds to the JSON property minimumChargingRateKw
3188 3189 3190 |
# File 'lib/google/apis/places_v1/classes.rb', line 3188 def minimum_charging_rate_kw @minimum_charging_rate_kw end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3195 3196 3197 3198 |
# File 'lib/google/apis/places_v1/classes.rb', line 3195 def update!(**args) @connector_types = args[:connector_types] if args.key?(:connector_types) @minimum_charging_rate_kw = args[:minimum_charging_rate_kw] if args.key?(:minimum_charging_rate_kw) end |