Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextRequestLocationBias
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextRequestLocationBias
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
The region to search. This location serves as a bias which means results around given location might be returned.
Instance Attribute Summary collapse
-
#circle ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1Circle
Circle with a LatLng as center and radius.
-
#rectangle ⇒ Google::Apis::PlacesV1::GoogleGeoTypeViewport
A latitude-longitude viewport, represented as two diagonally opposite
lowandhighpoints.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextRequestLocationBias
constructor
A new instance of GoogleMapsPlacesV1SearchTextRequestLocationBias.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextRequestLocationBias
Returns a new instance of GoogleMapsPlacesV1SearchTextRequestLocationBias.
3231 3232 3233 |
# File 'lib/google/apis/places_v1/classes.rb', line 3231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#circle ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1Circle
Circle with a LatLng as center and radius.
Corresponds to the JSON property circle
3209 3210 3211 |
# File 'lib/google/apis/places_v1/classes.rb', line 3209 def circle @circle end |
#rectangle ⇒ Google::Apis::PlacesV1::GoogleGeoTypeViewport
A latitude-longitude viewport, represented as two diagonally opposite low
and high points. A viewport is considered a closed region, i.e. it includes
its boundary. The latitude bounds must range between -90 to 90 degrees
inclusive, and the longitude bounds must range between -180 to 180 degrees
inclusive. Various cases include: - If low = high, the viewport consists
of that single point. - If low.longitude > high.longitude, the longitude
range is inverted (the viewport crosses the 180 degree longitude line). - If
low.longitude = -180 degrees and high.longitude = 180 degrees, the viewport
includes all longitudes. - If low.longitude = 180 degrees and high.
longitude = -180 degrees, the longitude range is empty. - If low.latitude >
high.latitude, the latitude range is empty. Both low and high must be
populated, and the represented box cannot be empty (as specified by the
definitions above). An empty viewport will result in an error. For example,
this viewport fully encloses New York City: "low": "latitude": 40.477398, "
longitude": -74.259087 , "high": "latitude": 40.91618, "longitude": -73.
70018
Corresponds to the JSON property rectangle
3229 3230 3231 |
# File 'lib/google/apis/places_v1/classes.rb', line 3229 def rectangle @rectangle end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3236 3237 3238 3239 |
# File 'lib/google/apis/places_v1/classes.rb', line 3236 def update!(**args) @circle = args[:circle] if args.key?(:circle) @rectangle = args[:rectangle] if args.key?(:rectangle) end |