Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextRequestLocationRestriction
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextRequestLocationRestriction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
The region to search. This location serves as a restriction which means results outside given location will not be returned.
Instance Attribute Summary collapse
-
#rectangle ⇒ Google::Apis::PlacesV1::GoogleGeoTypeViewport
A latitude-longitude viewport, represented as two diagonally opposite
lowandhighpoints.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextRequestLocationRestriction
constructor
A new instance of GoogleMapsPlacesV1SearchTextRequestLocationRestriction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextRequestLocationRestriction
Returns a new instance of GoogleMapsPlacesV1SearchTextRequestLocationRestriction.
3267 3268 3269 |
# File 'lib/google/apis/places_v1/classes.rb', line 3267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rectangle ⇒ Google::Apis::PlacesV1::GoogleGeoTypeViewport
A latitude-longitude viewport, represented as two diagonally opposite low
and high points. A viewport is considered a closed region, i.e. it includes
its boundary. The latitude bounds must range between -90 to 90 degrees
inclusive, and the longitude bounds must range between -180 to 180 degrees
inclusive. Various cases include: - If low = high, the viewport consists
of that single point. - If low.longitude > high.longitude, the longitude
range is inverted (the viewport crosses the 180 degree longitude line). - If
low.longitude = -180 degrees and high.longitude = 180 degrees, the viewport
includes all longitudes. - If low.longitude = 180 degrees and high.
longitude = -180 degrees, the longitude range is empty. - If low.latitude >
high.latitude, the latitude range is empty. Both low and high must be
populated, and the represented box cannot be empty (as specified by the
definitions above). An empty viewport will result in an error. For example,
this viewport fully encloses New York City: "low": "latitude": 40.477398, "
longitude": -74.259087 , "high": "latitude": 40.91618, "longitude": -73.
70018
Corresponds to the JSON property rectangle
3265 3266 3267 |
# File 'lib/google/apis/places_v1/classes.rb', line 3265 def rectangle @rectangle end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3272 3273 3274 |
# File 'lib/google/apis/places_v1/classes.rb', line 3272 def update!(**args) @rectangle = args[:rectangle] if args.key?(:rectangle) end |