Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitAgency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Represents a transit agency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1TransitAgency

Returns a new instance of GoogleMapsPlacesV1TransitAgency.



3476
3477
3478
# File 'lib/google/apis/places_v1/classes.rb', line 3476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property displayName



3454
3455
3456
# File 'lib/google/apis/places_v1/classes.rb', line 3454

def display_name
  @display_name
end

#fare_urlString

The URL of the agency's fare details page. Corresponds to the JSON property fareUrl

Returns:

  • (String)


3459
3460
3461
# File 'lib/google/apis/places_v1/classes.rb', line 3459

def fare_url
  @fare_url
end

#iconGoogle::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon

Icon for a transit line, vehicle, or agency. Corresponds to the JSON property icon



3464
3465
3466
# File 'lib/google/apis/places_v1/classes.rb', line 3464

def icon
  @icon
end

#linesArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitLine>

The transit lines that are served by this agency. Corresponds to the JSON property lines



3469
3470
3471
# File 'lib/google/apis/places_v1/classes.rb', line 3469

def lines
  @lines
end

#urlString

The URL of the agency's homepage. Corresponds to the JSON property url

Returns:

  • (String)


3474
3475
3476
# File 'lib/google/apis/places_v1/classes.rb', line 3474

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3481
3482
3483
3484
3485
3486
3487
# File 'lib/google/apis/places_v1/classes.rb', line 3481

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @fare_url = args[:fare_url] if args.key?(:fare_url)
  @icon = args[:icon] if args.key?(:icon)
  @lines = args[:lines] if args.key?(:lines)
  @url = args[:url] if args.key?(:url)
end