Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitLine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Represents a single transit line.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1TransitLine

Returns a new instance of GoogleMapsPlacesV1TransitLine.



3571
3572
3573
# File 'lib/google/apis/places_v1/classes.rb', line 3571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_colorString

The background color of the labels for this transit line in #RRGGBB hex format, e.g. #909CE1. This color can also be used for drawing shapes for this transit line. Corresponds to the JSON property backgroundColor

Returns:

  • (String)


3526
3527
3528
# File 'lib/google/apis/places_v1/classes.rb', line 3526

def background_color
  @background_color
end

#display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property displayName



3531
3532
3533
# File 'lib/google/apis/places_v1/classes.rb', line 3531

def display_name
  @display_name
end

#iconGoogle::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon

Icon for a transit line, vehicle, or agency. Corresponds to the JSON property icon



3536
3537
3538
# File 'lib/google/apis/places_v1/classes.rb', line 3536

def icon
  @icon
end

#idString

The id of the transit line that can be used to uniquely identify the line among other transit lines in the same transit station. This identifier is not guaranteed to be stable across different responses. Corresponds to the JSON property id

Returns:

  • (String)


3543
3544
3545
# File 'lib/google/apis/places_v1/classes.rb', line 3543

def id
  @id
end

#short_display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property shortDisplayName



3548
3549
3550
# File 'lib/google/apis/places_v1/classes.rb', line 3548

def short_display_name
  @short_display_name
end

#text_colorString

The text color of labels for this transit line in #RRGGBB hex format, e.g. # 909CE1. Corresponds to the JSON property textColor

Returns:

  • (String)


3554
3555
3556
# File 'lib/google/apis/places_v1/classes.rb', line 3554

def text_color
  @text_color
end

#urlString

The URL of a webpage with details about this line. Corresponds to the JSON property url

Returns:

  • (String)


3559
3560
3561
# File 'lib/google/apis/places_v1/classes.rb', line 3559

def url
  @url
end

#vehicle_iconGoogle::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon

Icon for a transit line, vehicle, or agency. Corresponds to the JSON property vehicleIcon



3564
3565
3566
# File 'lib/google/apis/places_v1/classes.rb', line 3564

def vehicle_icon
  @vehicle_icon
end

#vehicle_typeString

The type of vehicle using this line. Corresponds to the JSON property vehicleType

Returns:

  • (String)


3569
3570
3571
# File 'lib/google/apis/places_v1/classes.rb', line 3569

def vehicle_type
  @vehicle_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
# File 'lib/google/apis/places_v1/classes.rb', line 3576

def update!(**args)
  @background_color = args[:background_color] if args.key?(:background_color)
  @display_name = args[:display_name] if args.key?(:display_name)
  @icon = args[:icon] if args.key?(:icon)
  @id = args[:id] if args.key?(:id)
  @short_display_name = args[:short_display_name] if args.key?(:short_display_name)
  @text_color = args[:text_color] if args.key?(:text_color)
  @url = args[:url] if args.key?(:url)
  @vehicle_icon = args[:vehicle_icon] if args.key?(:vehicle_icon)
  @vehicle_type = args[:vehicle_type] if args.key?(:vehicle_type)
end