Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStation
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Represents transit-specific information for a place.
Instance Attribute Summary collapse
-
#agencies ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitAgency>
The transit agencies that serve this station.
-
#display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#stops ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStop>
Transit stops at this station.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1TransitStation
constructor
A new instance of GoogleMapsPlacesV1TransitStation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1TransitStation
Returns a new instance of GoogleMapsPlacesV1TransitStation.
3531 3532 3533 |
# File 'lib/google/apis/places_v1/classes.rb', line 3531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agencies ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitAgency>
The transit agencies that serve this station.
Corresponds to the JSON property agencies
3519 3520 3521 |
# File 'lib/google/apis/places_v1/classes.rb', line 3519 def agencies @agencies end |
#display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property displayName
3524 3525 3526 |
# File 'lib/google/apis/places_v1/classes.rb', line 3524 def display_name @display_name end |
#stops ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStop>
Transit stops at this station.
Corresponds to the JSON property stops
3529 3530 3531 |
# File 'lib/google/apis/places_v1/classes.rb', line 3529 def stops @stops end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3536 3537 3538 3539 3540 |
# File 'lib/google/apis/places_v1/classes.rb', line 3536 def update!(**args) @agencies = args[:agencies] if args.key?(:agencies) @display_name = args[:display_name] if args.key?(:display_name) @stops = args[:stops] if args.key?(:stops) end |