Class: Google::Apis::PlacesV1::GoogleTypeLatLng
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleTypeLatLng
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ Float
The latitude in degrees.
-
#longitude ⇒ Float
The longitude in degrees.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeLatLng
constructor
A new instance of GoogleTypeLatLng.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeLatLng
Returns a new instance of GoogleTypeLatLng.
3744 3745 3746 |
# File 'lib/google/apis/places_v1/classes.rb', line 3744 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latitude ⇒ Float
The latitude in degrees. It must be in the range [-90.0, +90.0].
Corresponds to the JSON property latitude
3737 3738 3739 |
# File 'lib/google/apis/places_v1/classes.rb', line 3737 def latitude @latitude end |
#longitude ⇒ Float
The longitude in degrees. It must be in the range [-180.0, +180.0].
Corresponds to the JSON property longitude
3742 3743 3744 |
# File 'lib/google/apis/places_v1/classes.rb', line 3742 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3749 3750 3751 3752 |
# File 'lib/google/apis/places_v1/classes.rb', line 3749 def update!(**args) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |