Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContent
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Content that is contextual to the place query.
Instance Attribute Summary collapse
-
#justifications ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustification>
Justifications for the place.
-
#photos ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Photo>
Information (including references) about photos of this place, contextual to the place query.
-
#reviews ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Review>
List of reviews about this place, contextual to the place query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1ContextualContent
constructor
A new instance of GoogleMapsPlacesV1ContextualContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1ContextualContent
Returns a new instance of GoogleMapsPlacesV1ContextualContent.
747 748 749 |
# File 'lib/google/apis/places_v1/classes.rb', line 747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#justifications ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContentJustification>
Justifications for the place.
Corresponds to the JSON property justifications
734 735 736 |
# File 'lib/google/apis/places_v1/classes.rb', line 734 def justifications @justifications end |
#photos ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Photo>
Information (including references) about photos of this place, contextual to
the place query.
Corresponds to the JSON property photos
740 741 742 |
# File 'lib/google/apis/places_v1/classes.rb', line 740 def photos @photos end |
#reviews ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Review>
List of reviews about this place, contextual to the place query.
Corresponds to the JSON property reviews
745 746 747 |
# File 'lib/google/apis/places_v1/classes.rb', line 745 def reviews @reviews end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
752 753 754 755 756 |
# File 'lib/google/apis/places_v1/classes.rb', line 752 def update!(**args) @justifications = args[:justifications] if args.key?(:justifications) @photos = args[:photos] if args.key?(:photos) @reviews = args[:reviews] if args.key?(:reviews) end |