Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PhotoMedia
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1PhotoMedia
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
A photo media from Places API.
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name of a photo media in the format:
places/place_id/photos/photo_reference/media. -
#photo_uri ⇒ String
A short-lived uri that can be used to render the photo.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1PhotoMedia
constructor
A new instance of GoogleMapsPlacesV1PhotoMedia.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1PhotoMedia
Returns a new instance of GoogleMapsPlacesV1PhotoMedia.
1107 1108 1109 |
# File 'lib/google/apis/places_v1/classes.rb', line 1107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The resource name of a photo media in the format: places/place_id/photos/
photo_reference/media.
Corresponds to the JSON property name
1100 1101 1102 |
# File 'lib/google/apis/places_v1/classes.rb', line 1100 def name @name end |
#photo_uri ⇒ String
A short-lived uri that can be used to render the photo.
Corresponds to the JSON property photoUri
1105 1106 1107 |
# File 'lib/google/apis/places_v1/classes.rb', line 1105 def photo_uri @photo_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1112 1113 1114 1115 |
# File 'lib/google/apis/places_v1/classes.rb', line 1112 def update!(**args) @name = args[:name] if args.key?(:name) @photo_uri = args[:photo_uri] if args.key?(:photo_uri) end |