Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1Place
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1Place
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
All the information representing a Place.
Instance Attribute Summary collapse
-
#accessibility_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAccessibilityOptions
Information about the accessibility options a place offers.
-
#address_components ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAddressComponent>
Repeated components for each locality level.
-
#address_descriptor ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1AddressDescriptor
A relational description of a location.
-
#adr_format_address ⇒ String
The place's address in adr microformat: http://microformats.org/wiki/adr.
-
#allows_dogs ⇒ Boolean
(also: #allows_dogs?)
Place allows dogs.
-
#attributions ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAttribution>
A set of data provider that must be shown with this result.
-
#business_status ⇒ String
The business status for the place.
-
#consumer_alert ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlert
The consumer alert message for the place when we detect suspicious review activity on a business or a business violates our policies.
-
#containing_places ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceContainingPlace>
List of places in which the current place is located.
-
#curbside_pickup ⇒ Boolean
(also: #curbside_pickup?)
Specifies if the business supports curbside pickup.
-
#current_opening_hours ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours
Information about business hour of the place.
-
#current_secondary_opening_hours ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours>
Contains an array of entries for the next seven days including information about secondary hours of a business.
-
#delivery ⇒ Boolean
(also: #delivery?)
Specifies if the business supports delivery.
-
#dine_in ⇒ Boolean
(also: #dine_in?)
Specifies if the business supports indoor or outdoor seating options.
-
#display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#editorial_summary ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#ev_charge_amenity_summary ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceEvChargeAmenitySummary
The summary of amenities near the EV charging station.
-
#ev_charge_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1EvChargeOptions
Information about the EV Charge Station hosted in Place.
-
#formatted_address ⇒ String
A full, human-readable address for this place.
-
#fuel_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1FuelOptions
The most recent information about fuel options in a gas station.
-
#generative_summary ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGenerativeSummary
AI-generated summary of the place.
-
#good_for_children ⇒ Boolean
(also: #good_for_children?)
Place is good for children.
-
#good_for_groups ⇒ Boolean
(also: #good_for_groups?)
Place accommodates groups.
-
#good_for_watching_sports ⇒ Boolean
(also: #good_for_watching_sports?)
Place is suitable for watching sports.
-
#google_maps_links ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGoogleMapsLinks
Links to trigger different Google Maps actions.
-
#google_maps_type_label ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#google_maps_uri ⇒ String
A URL providing more information about this place.
-
#icon_background_color ⇒ String
Background color for icon_mask in hex format, e.g.
-
#icon_mask_base_uri ⇒ String
A truncated URL to an icon mask.
-
#id ⇒ String
The unique identifier of a place.
-
#international_phone_number ⇒ String
A human-readable phone number for the place, in international format.
-
#live_music ⇒ Boolean
(also: #live_music?)
Place provides live music.
-
#location ⇒ Google::Apis::PlacesV1::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
-
#menu_for_children ⇒ Boolean
(also: #menu_for_children?)
Place has a children's menu.
-
#moved_place ⇒ String
If this Place is permanently closed and has moved to a new Place, this field contains the new Place's resource name, in
places/place_id`` format. -
#moved_place_id ⇒ String
If this Place is permanently closed and has moved to a new Place, this field contains the new Place's place ID.
-
#name ⇒ String
This Place's resource name, in
places/place_id`` format. -
#national_phone_number ⇒ String
A human-readable phone number for the place, in national format.
-
#neighborhood_summary ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceNeighborhoodSummary
A summary of points of interest near the place.
-
#opening_date ⇒ Google::Apis::PlacesV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#outdoor_seating ⇒ Boolean
(also: #outdoor_seating?)
Place provides outdoor seating.
-
#parking_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceParkingOptions
Information about parking options for the place.
-
#payment_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlacePaymentOptions
Payment options the place accepts.
-
#photos ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Photo>
Information (including references) about photos of this place.
-
#plus_code ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlacePlusCode
Plus code (http://plus.codes) is a location reference with two formats: global code defining a 14mx14m (1/8000th of a degree) or smaller rectangle, and compound code, replacing the prefix with a reference location.
-
#postal_address ⇒ Google::Apis::PlacesV1::GoogleTypePostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
-
#price_level ⇒ String
Price level of the place.
-
#price_range ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PriceRange
The price range associated with a Place.
-
#primary_type ⇒ String
The primary type of the given result.
-
#primary_type_display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#pure_service_area_business ⇒ Boolean
(also: #pure_service_area_business?)
Indicates whether the place is a pure service area business.
-
#rating ⇒ Float
A rating between 1.0 and 5.0, based on user reviews of this place.
-
#regular_opening_hours ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours
Information about business hour of the place.
-
#regular_secondary_opening_hours ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours>
Contains an array of entries for information about regular secondary hours of a business.
-
#reservable ⇒ Boolean
(also: #reservable?)
Specifies if the place supports reservations.
-
#restroom ⇒ Boolean
(also: #restroom?)
Place has restroom.
-
#review_summary ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceReviewSummary
AI-generated summary of the place using user reviews.
-
#reviews ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Review>
List of reviews about this place, sorted by relevance.
-
#serves_beer ⇒ Boolean
(also: #serves_beer?)
Specifies if the place serves beer.
-
#serves_breakfast ⇒ Boolean
(also: #serves_breakfast?)
Specifies if the place serves breakfast.
-
#serves_brunch ⇒ Boolean
(also: #serves_brunch?)
Specifies if the place serves brunch.
-
#serves_cocktails ⇒ Boolean
(also: #serves_cocktails?)
Place serves cocktails.
-
#serves_coffee ⇒ Boolean
(also: #serves_coffee?)
Place serves coffee.
-
#serves_dessert ⇒ Boolean
(also: #serves_dessert?)
Place serves dessert.
-
#serves_dinner ⇒ Boolean
(also: #serves_dinner?)
Specifies if the place serves dinner.
-
#serves_lunch ⇒ Boolean
(also: #serves_lunch?)
Specifies if the place serves lunch.
-
#serves_vegetarian_food ⇒ Boolean
(also: #serves_vegetarian_food?)
Specifies if the place serves vegetarian food.
-
#serves_wine ⇒ Boolean
(also: #serves_wine?)
Specifies if the place serves wine.
-
#short_formatted_address ⇒ String
A short, human-readable address for this place.
-
#sub_destinations ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceSubDestination>
A list of sub-destinations related to the place.
-
#takeout ⇒ Boolean
(also: #takeout?)
Specifies if the business supports takeout.
-
#time_zone ⇒ Google::Apis::PlacesV1::GoogleTypeTimeZone
Represents a time zone from the IANA Time Zone Database.
-
#transit_station ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStation
Represents transit-specific information for a place.
-
#types ⇒ Array<String>
A set of type tags for this result.
-
#user_rating_count ⇒ Fixnum
The total number of reviews (with or without text) for this place.
-
#utc_offset_minutes ⇒ Fixnum
Number of minutes this place's timezone is currently offset from UTC.
-
#viewport ⇒ Google::Apis::PlacesV1::GoogleGeoTypeViewport
A latitude-longitude viewport, represented as two diagonally opposite
lowandhighpoints. -
#website_uri ⇒ String
The authoritative website for this place, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1Place
constructor
A new instance of GoogleMapsPlacesV1Place.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1Place
Returns a new instance of GoogleMapsPlacesV1Place.
1634 1635 1636 |
# File 'lib/google/apis/places_v1/classes.rb', line 1634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accessibility_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAccessibilityOptions
Information about the accessibility options a place offers.
Corresponds to the JSON property accessibilityOptions
1125 1126 1127 |
# File 'lib/google/apis/places_v1/classes.rb', line 1125 def @accessibility_options end |
#address_components ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAddressComponent>
Repeated components for each locality level. Note the following facts about
the address_components[] array: - The array of address components may contain
more components than the formatted_address. - The array does not necessarily
include all the political entities that contain an address, apart from those
included in the formatted_address. To retrieve all the political entities that
contain a specific address, you should use reverse geocoding, passing the
latitude/longitude of the address as a parameter to the request. - The format
of the response is not guaranteed to remain the same between requests. In
particular, the number of address_components varies based on the address
requested and can change over time for the same address. A component can
change position in the array. The type of the component can change. A
particular component may be missing in a later response.
Corresponds to the JSON property addressComponents
1141 1142 1143 |
# File 'lib/google/apis/places_v1/classes.rb', line 1141 def address_components @address_components end |
#address_descriptor ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1AddressDescriptor
A relational description of a location. Includes a ranked set of nearby
landmarks and precise containing areas and their relationship to the target
location.
Corresponds to the JSON property addressDescriptor
1148 1149 1150 |
# File 'lib/google/apis/places_v1/classes.rb', line 1148 def address_descriptor @address_descriptor end |
#adr_format_address ⇒ String
The place's address in adr microformat: http://microformats.org/wiki/adr.
Corresponds to the JSON property adrFormatAddress
1153 1154 1155 |
# File 'lib/google/apis/places_v1/classes.rb', line 1153 def adr_format_address @adr_format_address end |
#allows_dogs ⇒ Boolean Also known as: allows_dogs?
Place allows dogs.
Corresponds to the JSON property allowsDogs
1158 1159 1160 |
# File 'lib/google/apis/places_v1/classes.rb', line 1158 def allows_dogs @allows_dogs end |
#attributions ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAttribution>
A set of data provider that must be shown with this result.
Corresponds to the JSON property attributions
1164 1165 1166 |
# File 'lib/google/apis/places_v1/classes.rb', line 1164 def attributions @attributions end |
#business_status ⇒ String
The business status for the place.
Corresponds to the JSON property businessStatus
1169 1170 1171 |
# File 'lib/google/apis/places_v1/classes.rb', line 1169 def business_status @business_status end |
#consumer_alert ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlert
The consumer alert message for the place when we detect suspicious review
activity on a business or a business violates our policies.
Corresponds to the JSON property consumerAlert
1175 1176 1177 |
# File 'lib/google/apis/places_v1/classes.rb', line 1175 def consumer_alert @consumer_alert end |
#containing_places ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceContainingPlace>
List of places in which the current place is located.
Corresponds to the JSON property containingPlaces
1180 1181 1182 |
# File 'lib/google/apis/places_v1/classes.rb', line 1180 def containing_places @containing_places end |
#curbside_pickup ⇒ Boolean Also known as: curbside_pickup?
Specifies if the business supports curbside pickup.
Corresponds to the JSON property curbsidePickup
1185 1186 1187 |
# File 'lib/google/apis/places_v1/classes.rb', line 1185 def curbside_pickup @curbside_pickup end |
#current_opening_hours ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours
Information about business hour of the place.
Corresponds to the JSON property currentOpeningHours
1191 1192 1193 |
# File 'lib/google/apis/places_v1/classes.rb', line 1191 def current_opening_hours @current_opening_hours end |
#current_secondary_opening_hours ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours>
Contains an array of entries for the next seven days including information
about secondary hours of a business. Secondary hours are different from a
business's main hours. For example, a restaurant can specify drive through
hours or delivery hours as its secondary hours. This field populates the type
subfield, which draws from a predefined list of opening hours types (such as
DRIVE_THROUGH, PICKUP, or TAKEOUT) based on the types of the place. This field
includes the special_days subfield of all hours, set for dates that have
exceptional hours.
Corresponds to the JSON property currentSecondaryOpeningHours
1203 1204 1205 |
# File 'lib/google/apis/places_v1/classes.rb', line 1203 def current_secondary_opening_hours @current_secondary_opening_hours end |
#delivery ⇒ Boolean Also known as: delivery?
Specifies if the business supports delivery.
Corresponds to the JSON property delivery
1208 1209 1210 |
# File 'lib/google/apis/places_v1/classes.rb', line 1208 def delivery @delivery end |
#dine_in ⇒ Boolean Also known as: dine_in?
Specifies if the business supports indoor or outdoor seating options.
Corresponds to the JSON property dineIn
1214 1215 1216 |
# File 'lib/google/apis/places_v1/classes.rb', line 1214 def dine_in @dine_in end |
#display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property displayName
1220 1221 1222 |
# File 'lib/google/apis/places_v1/classes.rb', line 1220 def display_name @display_name end |
#editorial_summary ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property editorialSummary
1225 1226 1227 |
# File 'lib/google/apis/places_v1/classes.rb', line 1225 def editorial_summary @editorial_summary end |
#ev_charge_amenity_summary ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceEvChargeAmenitySummary
The summary of amenities near the EV charging station. This only applies to
places with type electric_vehicle_charging_station. The overview field is
guaranteed to be provided while the other fields are optional.
Corresponds to the JSON property evChargeAmenitySummary
1232 1233 1234 |
# File 'lib/google/apis/places_v1/classes.rb', line 1232 def ev_charge_amenity_summary @ev_charge_amenity_summary end |
#ev_charge_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1EvChargeOptions
Information about the EV Charge Station hosted in Place. Terminology follows
https://afdc.energy.gov/fuels/electricity_infrastructure.html One port could
charge one car at a time. One port has one or more connectors. One station has
one or more ports.
Corresponds to the JSON property evChargeOptions
1240 1241 1242 |
# File 'lib/google/apis/places_v1/classes.rb', line 1240 def @ev_charge_options end |
#formatted_address ⇒ String
A full, human-readable address for this place.
Corresponds to the JSON property formattedAddress
1245 1246 1247 |
# File 'lib/google/apis/places_v1/classes.rb', line 1245 def formatted_address @formatted_address end |
#fuel_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1FuelOptions
The most recent information about fuel options in a gas station. This
information is updated regularly.
Corresponds to the JSON property fuelOptions
1251 1252 1253 |
# File 'lib/google/apis/places_v1/classes.rb', line 1251 def @fuel_options end |
#generative_summary ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGenerativeSummary
AI-generated summary of the place.
Corresponds to the JSON property generativeSummary
1256 1257 1258 |
# File 'lib/google/apis/places_v1/classes.rb', line 1256 def generative_summary @generative_summary end |
#good_for_children ⇒ Boolean Also known as: good_for_children?
Place is good for children.
Corresponds to the JSON property goodForChildren
1261 1262 1263 |
# File 'lib/google/apis/places_v1/classes.rb', line 1261 def good_for_children @good_for_children end |
#good_for_groups ⇒ Boolean Also known as: good_for_groups?
Place accommodates groups.
Corresponds to the JSON property goodForGroups
1267 1268 1269 |
# File 'lib/google/apis/places_v1/classes.rb', line 1267 def good_for_groups @good_for_groups end |
#good_for_watching_sports ⇒ Boolean Also known as: good_for_watching_sports?
Place is suitable for watching sports.
Corresponds to the JSON property goodForWatchingSports
1273 1274 1275 |
# File 'lib/google/apis/places_v1/classes.rb', line 1273 def good_for_watching_sports @good_for_watching_sports end |
#google_maps_links ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGoogleMapsLinks
Links to trigger different Google Maps actions.
Corresponds to the JSON property googleMapsLinks
1279 1280 1281 |
# File 'lib/google/apis/places_v1/classes.rb', line 1279 def google_maps_links @google_maps_links end |
#google_maps_type_label ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property googleMapsTypeLabel
1284 1285 1286 |
# File 'lib/google/apis/places_v1/classes.rb', line 1284 def google_maps_type_label @google_maps_type_label end |
#google_maps_uri ⇒ String
A URL providing more information about this place.
Corresponds to the JSON property googleMapsUri
1289 1290 1291 |
# File 'lib/google/apis/places_v1/classes.rb', line 1289 def google_maps_uri @google_maps_uri end |
#icon_background_color ⇒ String
Background color for icon_mask in hex format, e.g. #909CE1.
Corresponds to the JSON property iconBackgroundColor
1294 1295 1296 |
# File 'lib/google/apis/places_v1/classes.rb', line 1294 def icon_background_color @icon_background_color end |
#icon_mask_base_uri ⇒ String
A truncated URL to an icon mask. User can access different icon type by
appending type suffix to the end (eg, ".svg" or ".png").
Corresponds to the JSON property iconMaskBaseUri
1300 1301 1302 |
# File 'lib/google/apis/places_v1/classes.rb', line 1300 def icon_mask_base_uri @icon_mask_base_uri end |
#id ⇒ String
The unique identifier of a place.
Corresponds to the JSON property id
1305 1306 1307 |
# File 'lib/google/apis/places_v1/classes.rb', line 1305 def id @id end |
#international_phone_number ⇒ String
A human-readable phone number for the place, in international format.
Corresponds to the JSON property internationalPhoneNumber
1310 1311 1312 |
# File 'lib/google/apis/places_v1/classes.rb', line 1310 def international_phone_number @international_phone_number end |
#live_music ⇒ Boolean Also known as: live_music?
Place provides live music.
Corresponds to the JSON property liveMusic
1315 1316 1317 |
# File 'lib/google/apis/places_v1/classes.rb', line 1315 def live_music @live_music end |
#location ⇒ Google::Apis::PlacesV1::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property location
1324 1325 1326 |
# File 'lib/google/apis/places_v1/classes.rb', line 1324 def location @location end |
#menu_for_children ⇒ Boolean Also known as:
Place has a children's menu.
Corresponds to the JSON property menuForChildren
1329 1330 1331 |
# File 'lib/google/apis/places_v1/classes.rb', line 1329 def @menu_for_children end |
#moved_place ⇒ String
If this Place is permanently closed and has moved to a new Place, this field
contains the new Place's resource name, in places/place_id`format. If this
Place moved multiple times, this field will represent the first moved place.
This field will not be populated if this Place has not moved.
Corresponds to the JSON propertymovedPlace`
1338 1339 1340 |
# File 'lib/google/apis/places_v1/classes.rb', line 1338 def moved_place @moved_place end |
#moved_place_id ⇒ String
If this Place is permanently closed and has moved to a new Place, this field
contains the new Place's place ID. If this Place moved multiple times, this
field will represent the first moved Place. This field will not be populated
if this Place has not moved.
Corresponds to the JSON property movedPlaceId
1346 1347 1348 |
# File 'lib/google/apis/places_v1/classes.rb', line 1346 def moved_place_id @moved_place_id end |
#name ⇒ String
This Place's resource name, in places/place_id`format. Can be used to look
up the Place.
Corresponds to the JSON propertyname`
1352 1353 1354 |
# File 'lib/google/apis/places_v1/classes.rb', line 1352 def name @name end |
#national_phone_number ⇒ String
A human-readable phone number for the place, in national format.
Corresponds to the JSON property nationalPhoneNumber
1357 1358 1359 |
# File 'lib/google/apis/places_v1/classes.rb', line 1357 def national_phone_number @national_phone_number end |
#neighborhood_summary ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceNeighborhoodSummary
A summary of points of interest near the place.
Corresponds to the JSON property neighborhoodSummary
1362 1363 1364 |
# File 'lib/google/apis/places_v1/classes.rb', line 1362 def neighborhood_summary @neighborhood_summary end |
#opening_date ⇒ Google::Apis::PlacesV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property openingDate
1374 1375 1376 |
# File 'lib/google/apis/places_v1/classes.rb', line 1374 def opening_date @opening_date end |
#outdoor_seating ⇒ Boolean Also known as: outdoor_seating?
Place provides outdoor seating.
Corresponds to the JSON property outdoorSeating
1379 1380 1381 |
# File 'lib/google/apis/places_v1/classes.rb', line 1379 def outdoor_seating @outdoor_seating end |
#parking_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceParkingOptions
Information about parking options for the place. A parking lot could support
more than one option at the same time.
Corresponds to the JSON property parkingOptions
1386 1387 1388 |
# File 'lib/google/apis/places_v1/classes.rb', line 1386 def @parking_options end |
#payment_options ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlacePaymentOptions
Payment options the place accepts.
Corresponds to the JSON property paymentOptions
1391 1392 1393 |
# File 'lib/google/apis/places_v1/classes.rb', line 1391 def @payment_options end |
#photos ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Photo>
Information (including references) about photos of this place. A maximum of 10
photos can be returned.
Corresponds to the JSON property photos
1397 1398 1399 |
# File 'lib/google/apis/places_v1/classes.rb', line 1397 def photos @photos end |
#plus_code ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlacePlusCode
Plus code (http://plus.codes) is a location reference with two formats: global
code defining a 14mx14m (1/8000th of a degree) or smaller rectangle, and
compound code, replacing the prefix with a reference location.
Corresponds to the JSON property plusCode
1404 1405 1406 |
# File 'lib/google/apis/places_v1/classes.rb', line 1404 def plus_code @plus_code end |
#postal_address ⇒ Google::Apis::PlacesV1::GoogleTypePostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property postalAddress
1419 1420 1421 |
# File 'lib/google/apis/places_v1/classes.rb', line 1419 def postal_address @postal_address end |
#price_level ⇒ String
Price level of the place.
Corresponds to the JSON property priceLevel
1424 1425 1426 |
# File 'lib/google/apis/places_v1/classes.rb', line 1424 def price_level @price_level end |
#price_range ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PriceRange
The price range associated with a Place. end_price could be unset, which
indicates a range without upper bound (e.g. "More than $100").
Corresponds to the JSON property priceRange
1430 1431 1432 |
# File 'lib/google/apis/places_v1/classes.rb', line 1430 def price_range @price_range end |
#primary_type ⇒ String
The primary type of the given result. This type must be one of the Places API
supported types. For example, "restaurant", "cafe", "airport", etc. A place
can only have a single primary type. For the complete list of possible values,
see Table A and Table B at https://developers.google.com/maps/documentation/
places/web-service/place-types. The primary type may be missing if the place's
primary type is not a supported type. When a primary type is present, it is
always one of the types in the types field.
Corresponds to the JSON property primaryType
1441 1442 1443 |
# File 'lib/google/apis/places_v1/classes.rb', line 1441 def primary_type @primary_type end |
#primary_type_display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property primaryTypeDisplayName
1446 1447 1448 |
# File 'lib/google/apis/places_v1/classes.rb', line 1446 def primary_type_display_name @primary_type_display_name end |
#pure_service_area_business ⇒ Boolean Also known as: pure_service_area_business?
Indicates whether the place is a pure service area business. Pure service area
business is a business that visits or delivers to customers directly but does
not serve customers at their business address. For example, businesses like
cleaning services or plumbers. Those businesses may not have a physical
address or location on Google Maps.
Corresponds to the JSON property pureServiceAreaBusiness
1455 1456 1457 |
# File 'lib/google/apis/places_v1/classes.rb', line 1455 def pure_service_area_business @pure_service_area_business end |
#rating ⇒ Float
A rating between 1.0 and 5.0, based on user reviews of this place.
Corresponds to the JSON property rating
1461 1462 1463 |
# File 'lib/google/apis/places_v1/classes.rb', line 1461 def @rating end |
#regular_opening_hours ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours
Information about business hour of the place.
Corresponds to the JSON property regularOpeningHours
1466 1467 1468 |
# File 'lib/google/apis/places_v1/classes.rb', line 1466 def regular_opening_hours @regular_opening_hours end |
#regular_secondary_opening_hours ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours>
Contains an array of entries for information about regular secondary hours of
a business. Secondary hours are different from a business's main hours. For
example, a restaurant can specify drive through hours or delivery hours as its
secondary hours. This field populates the type subfield, which draws from a
predefined list of opening hours types (such as DRIVE_THROUGH, PICKUP, or
TAKEOUT) based on the types of the place.
Corresponds to the JSON property regularSecondaryOpeningHours
1476 1477 1478 |
# File 'lib/google/apis/places_v1/classes.rb', line 1476 def regular_secondary_opening_hours @regular_secondary_opening_hours end |
#reservable ⇒ Boolean Also known as: reservable?
Specifies if the place supports reservations.
Corresponds to the JSON property reservable
1481 1482 1483 |
# File 'lib/google/apis/places_v1/classes.rb', line 1481 def reservable @reservable end |
#restroom ⇒ Boolean Also known as: restroom?
Place has restroom.
Corresponds to the JSON property restroom
1487 1488 1489 |
# File 'lib/google/apis/places_v1/classes.rb', line 1487 def restroom @restroom end |
#review_summary ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceReviewSummary
AI-generated summary of the place using user reviews.
Corresponds to the JSON property reviewSummary
1493 1494 1495 |
# File 'lib/google/apis/places_v1/classes.rb', line 1493 def review_summary @review_summary end |
#reviews ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Review>
List of reviews about this place, sorted by relevance. A maximum of 5 reviews
can be returned.
Corresponds to the JSON property reviews
1499 1500 1501 |
# File 'lib/google/apis/places_v1/classes.rb', line 1499 def reviews @reviews end |
#serves_beer ⇒ Boolean Also known as: serves_beer?
Specifies if the place serves beer.
Corresponds to the JSON property servesBeer
1504 1505 1506 |
# File 'lib/google/apis/places_v1/classes.rb', line 1504 def serves_beer @serves_beer end |
#serves_breakfast ⇒ Boolean Also known as: serves_breakfast?
Specifies if the place serves breakfast.
Corresponds to the JSON property servesBreakfast
1510 1511 1512 |
# File 'lib/google/apis/places_v1/classes.rb', line 1510 def serves_breakfast @serves_breakfast end |
#serves_brunch ⇒ Boolean Also known as: serves_brunch?
Specifies if the place serves brunch.
Corresponds to the JSON property servesBrunch
1516 1517 1518 |
# File 'lib/google/apis/places_v1/classes.rb', line 1516 def serves_brunch @serves_brunch end |
#serves_cocktails ⇒ Boolean Also known as: serves_cocktails?
Place serves cocktails.
Corresponds to the JSON property servesCocktails
1522 1523 1524 |
# File 'lib/google/apis/places_v1/classes.rb', line 1522 def serves_cocktails @serves_cocktails end |
#serves_coffee ⇒ Boolean Also known as: serves_coffee?
Place serves coffee.
Corresponds to the JSON property servesCoffee
1528 1529 1530 |
# File 'lib/google/apis/places_v1/classes.rb', line 1528 def serves_coffee @serves_coffee end |
#serves_dessert ⇒ Boolean Also known as: serves_dessert?
Place serves dessert.
Corresponds to the JSON property servesDessert
1534 1535 1536 |
# File 'lib/google/apis/places_v1/classes.rb', line 1534 def serves_dessert @serves_dessert end |
#serves_dinner ⇒ Boolean Also known as: serves_dinner?
Specifies if the place serves dinner.
Corresponds to the JSON property servesDinner
1540 1541 1542 |
# File 'lib/google/apis/places_v1/classes.rb', line 1540 def serves_dinner @serves_dinner end |
#serves_lunch ⇒ Boolean Also known as: serves_lunch?
Specifies if the place serves lunch.
Corresponds to the JSON property servesLunch
1546 1547 1548 |
# File 'lib/google/apis/places_v1/classes.rb', line 1546 def serves_lunch @serves_lunch end |
#serves_vegetarian_food ⇒ Boolean Also known as: serves_vegetarian_food?
Specifies if the place serves vegetarian food.
Corresponds to the JSON property servesVegetarianFood
1552 1553 1554 |
# File 'lib/google/apis/places_v1/classes.rb', line 1552 def serves_vegetarian_food @serves_vegetarian_food end |
#serves_wine ⇒ Boolean Also known as: serves_wine?
Specifies if the place serves wine.
Corresponds to the JSON property servesWine
1558 1559 1560 |
# File 'lib/google/apis/places_v1/classes.rb', line 1558 def serves_wine @serves_wine end |
#short_formatted_address ⇒ String
A short, human-readable address for this place.
Corresponds to the JSON property shortFormattedAddress
1564 1565 1566 |
# File 'lib/google/apis/places_v1/classes.rb', line 1564 def short_formatted_address @short_formatted_address end |
#sub_destinations ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceSubDestination>
A list of sub-destinations related to the place.
Corresponds to the JSON property subDestinations
1569 1570 1571 |
# File 'lib/google/apis/places_v1/classes.rb', line 1569 def sub_destinations @sub_destinations end |
#takeout ⇒ Boolean Also known as: takeout?
Specifies if the business supports takeout.
Corresponds to the JSON property takeout
1574 1575 1576 |
# File 'lib/google/apis/places_v1/classes.rb', line 1574 def takeout @takeout end |
#time_zone ⇒ Google::Apis::PlacesV1::GoogleTypeTimeZone
Represents a time zone from the IANA Time Zone Database.
Corresponds to the JSON property timeZone
1581 1582 1583 |
# File 'lib/google/apis/places_v1/classes.rb', line 1581 def time_zone @time_zone end |
#transit_station ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStation
Represents transit-specific information for a place.
Corresponds to the JSON property transitStation
1586 1587 1588 |
# File 'lib/google/apis/places_v1/classes.rb', line 1586 def transit_station @transit_station end |
#types ⇒ Array<String>
A set of type tags for this result. For example, "political" and "locality".
For the complete list of possible values, see Table A and Table B at https://
developers.google.com/maps/documentation/places/web-service/place-types
Corresponds to the JSON property types
1593 1594 1595 |
# File 'lib/google/apis/places_v1/classes.rb', line 1593 def types @types end |
#user_rating_count ⇒ Fixnum
The total number of reviews (with or without text) for this place.
Corresponds to the JSON property userRatingCount
1598 1599 1600 |
# File 'lib/google/apis/places_v1/classes.rb', line 1598 def @user_rating_count end |
#utc_offset_minutes ⇒ Fixnum
Number of minutes this place's timezone is currently offset from UTC. This is
expressed in minutes to support timezones that are offset by fractions of an
hour, e.g. X hours and 15 minutes.
Corresponds to the JSON property utcOffsetMinutes
1605 1606 1607 |
# File 'lib/google/apis/places_v1/classes.rb', line 1605 def utc_offset_minutes @utc_offset_minutes end |
#viewport ⇒ Google::Apis::PlacesV1::GoogleGeoTypeViewport
A latitude-longitude viewport, represented as two diagonally opposite low
and high points. A viewport is considered a closed region, i.e. it includes
its boundary. The latitude bounds must range between -90 to 90 degrees
inclusive, and the longitude bounds must range between -180 to 180 degrees
inclusive. Various cases include: - If low = high, the viewport consists
of that single point. - If low.longitude > high.longitude, the longitude
range is inverted (the viewport crosses the 180 degree longitude line). - If
low.longitude = -180 degrees and high.longitude = 180 degrees, the viewport
includes all longitudes. - If low.longitude = 180 degrees and high.
longitude = -180 degrees, the longitude range is empty. - If low.latitude >
high.latitude, the latitude range is empty. Both low and high must be
populated, and the represented box cannot be empty (as specified by the
definitions above). An empty viewport will result in an error. For example,
this viewport fully encloses New York City: "low": "latitude": 40.477398, "
longitude": -74.259087 , "high": "latitude": 40.91618, "longitude": -73.
70018
Corresponds to the JSON property viewport
1625 1626 1627 |
# File 'lib/google/apis/places_v1/classes.rb', line 1625 def @viewport end |
#website_uri ⇒ String
The authoritative website for this place, e.g. a business' homepage. Note that
for places that are part of a chain (e.g. an IKEA store), this will usually be
the website for the individual store, not the overall chain.
Corresponds to the JSON property websiteUri
1632 1633 1634 |
# File 'lib/google/apis/places_v1/classes.rb', line 1632 def website_uri @website_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 |
# File 'lib/google/apis/places_v1/classes.rb', line 1639 def update!(**args) @accessibility_options = args[:accessibility_options] if args.key?(:accessibility_options) @address_components = args[:address_components] if args.key?(:address_components) @address_descriptor = args[:address_descriptor] if args.key?(:address_descriptor) @adr_format_address = args[:adr_format_address] if args.key?(:adr_format_address) @allows_dogs = args[:allows_dogs] if args.key?(:allows_dogs) @attributions = args[:attributions] if args.key?(:attributions) @business_status = args[:business_status] if args.key?(:business_status) @consumer_alert = args[:consumer_alert] if args.key?(:consumer_alert) @containing_places = args[:containing_places] if args.key?(:containing_places) @curbside_pickup = args[:curbside_pickup] if args.key?(:curbside_pickup) @current_opening_hours = args[:current_opening_hours] if args.key?(:current_opening_hours) @current_secondary_opening_hours = args[:current_secondary_opening_hours] if args.key?(:current_secondary_opening_hours) @delivery = args[:delivery] if args.key?(:delivery) @dine_in = args[:dine_in] if args.key?(:dine_in) @display_name = args[:display_name] if args.key?(:display_name) @editorial_summary = args[:editorial_summary] if args.key?(:editorial_summary) @ev_charge_amenity_summary = args[:ev_charge_amenity_summary] if args.key?(:ev_charge_amenity_summary) @ev_charge_options = args[:ev_charge_options] if args.key?(:ev_charge_options) @formatted_address = args[:formatted_address] if args.key?(:formatted_address) @fuel_options = args[:fuel_options] if args.key?(:fuel_options) @generative_summary = args[:generative_summary] if args.key?(:generative_summary) @good_for_children = args[:good_for_children] if args.key?(:good_for_children) @good_for_groups = args[:good_for_groups] if args.key?(:good_for_groups) @good_for_watching_sports = args[:good_for_watching_sports] if args.key?(:good_for_watching_sports) @google_maps_links = args[:google_maps_links] if args.key?(:google_maps_links) @google_maps_type_label = args[:google_maps_type_label] if args.key?(:google_maps_type_label) @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri) @icon_background_color = args[:icon_background_color] if args.key?(:icon_background_color) @icon_mask_base_uri = args[:icon_mask_base_uri] if args.key?(:icon_mask_base_uri) @id = args[:id] if args.key?(:id) @international_phone_number = args[:international_phone_number] if args.key?(:international_phone_number) @live_music = args[:live_music] if args.key?(:live_music) @location = args[:location] if args.key?(:location) @menu_for_children = args[:menu_for_children] if args.key?(:menu_for_children) @moved_place = args[:moved_place] if args.key?(:moved_place) @moved_place_id = args[:moved_place_id] if args.key?(:moved_place_id) @name = args[:name] if args.key?(:name) @national_phone_number = args[:national_phone_number] if args.key?(:national_phone_number) @neighborhood_summary = args[:neighborhood_summary] if args.key?(:neighborhood_summary) @opening_date = args[:opening_date] if args.key?(:opening_date) @outdoor_seating = args[:outdoor_seating] if args.key?(:outdoor_seating) @parking_options = args[:parking_options] if args.key?(:parking_options) @payment_options = args[:payment_options] if args.key?(:payment_options) @photos = args[:photos] if args.key?(:photos) @plus_code = args[:plus_code] if args.key?(:plus_code) @postal_address = args[:postal_address] if args.key?(:postal_address) @price_level = args[:price_level] if args.key?(:price_level) @price_range = args[:price_range] if args.key?(:price_range) @primary_type = args[:primary_type] if args.key?(:primary_type) @primary_type_display_name = args[:primary_type_display_name] if args.key?(:primary_type_display_name) @pure_service_area_business = args[:pure_service_area_business] if args.key?(:pure_service_area_business) @rating = args[:rating] if args.key?(:rating) @regular_opening_hours = args[:regular_opening_hours] if args.key?(:regular_opening_hours) @regular_secondary_opening_hours = args[:regular_secondary_opening_hours] if args.key?(:regular_secondary_opening_hours) @reservable = args[:reservable] if args.key?(:reservable) @restroom = args[:restroom] if args.key?(:restroom) @review_summary = args[:review_summary] if args.key?(:review_summary) @reviews = args[:reviews] if args.key?(:reviews) @serves_beer = args[:serves_beer] if args.key?(:serves_beer) @serves_breakfast = args[:serves_breakfast] if args.key?(:serves_breakfast) @serves_brunch = args[:serves_brunch] if args.key?(:serves_brunch) @serves_cocktails = args[:serves_cocktails] if args.key?(:serves_cocktails) @serves_coffee = args[:serves_coffee] if args.key?(:serves_coffee) @serves_dessert = args[:serves_dessert] if args.key?(:serves_dessert) @serves_dinner = args[:serves_dinner] if args.key?(:serves_dinner) @serves_lunch = args[:serves_lunch] if args.key?(:serves_lunch) @serves_vegetarian_food = args[:serves_vegetarian_food] if args.key?(:serves_vegetarian_food) @serves_wine = args[:serves_wine] if args.key?(:serves_wine) @short_formatted_address = args[:short_formatted_address] if args.key?(:short_formatted_address) @sub_destinations = args[:sub_destinations] if args.key?(:sub_destinations) @takeout = args[:takeout] if args.key?(:takeout) @time_zone = args[:time_zone] if args.key?(:time_zone) @transit_station = args[:transit_station] if args.key?(:transit_station) @types = args[:types] if args.key?(:types) @user_rating_count = args[:user_rating_count] if args.key?(:user_rating_count) @utc_offset_minutes = args[:utc_offset_minutes] if args.key?(:utc_offset_minutes) @viewport = args[:viewport] if args.key?(:viewport) @website_uri = args[:website_uri] if args.key?(:website_uri) end |