Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1Place

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

All the information representing a Place.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1Place

Returns a new instance of GoogleMapsPlacesV1Place.



1641
1642
1643
# File 'lib/google/apis/places_v1/classes.rb', line 1641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessibility_optionsGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAccessibilityOptions

Information about the accessibility options a place offers. Corresponds to the JSON property accessibilityOptions



1137
1138
1139
# File 'lib/google/apis/places_v1/classes.rb', line 1137

def accessibility_options
  @accessibility_options
end

#address_componentsArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAddressComponent>

Repeated components for each locality level. Note the following facts about the address_components[] array: - The array of address components may contain more components than the formatted_address. - The array does not necessarily include all the political entities that contain an address, apart from those included in the formatted_address. To retrieve all the political entities that contain a specific address, you should use reverse geocoding, passing the latitude/longitude of the address as a parameter to the request. - The format of the response is not guaranteed to remain the same between requests. In particular, the number of address_components varies based on the address requested and can change over time for the same address. A component can change position in the array. The type of the component can change. A particular component may be missing in a later response. Corresponds to the JSON property addressComponents



1153
1154
1155
# File 'lib/google/apis/places_v1/classes.rb', line 1153

def address_components
  @address_components
end

#address_descriptorGoogle::Apis::PlacesV1::GoogleMapsPlacesV1AddressDescriptor

A relational description of a location. Includes a ranked set of nearby landmarks and precise containing areas and their relationship to the target location. Corresponds to the JSON property addressDescriptor



1160
1161
1162
# File 'lib/google/apis/places_v1/classes.rb', line 1160

def address_descriptor
  @address_descriptor
end

#adr_format_addressString

The place's address in adr microformat: http://microformats.org/wiki/adr. Corresponds to the JSON property adrFormatAddress

Returns:

  • (String)


1165
1166
1167
# File 'lib/google/apis/places_v1/classes.rb', line 1165

def adr_format_address
  @adr_format_address
end

#allows_dogsBoolean Also known as: allows_dogs?

Place allows dogs. Corresponds to the JSON property allowsDogs

Returns:

  • (Boolean)


1170
1171
1172
# File 'lib/google/apis/places_v1/classes.rb', line 1170

def allows_dogs
  @allows_dogs
end

#attributionsArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceAttribution>

A set of data provider that must be shown with this result. Corresponds to the JSON property attributions



1176
1177
1178
# File 'lib/google/apis/places_v1/classes.rb', line 1176

def attributions
  @attributions
end

#business_statusString

The business status for the place. Corresponds to the JSON property businessStatus

Returns:

  • (String)


1181
1182
1183
# File 'lib/google/apis/places_v1/classes.rb', line 1181

def business_status
  @business_status
end

#consumer_alertGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlert

The consumer alert message for the place when we detect suspicious review activity on a business or a business violates our policies. Corresponds to the JSON property consumerAlert



1187
1188
1189
# File 'lib/google/apis/places_v1/classes.rb', line 1187

def consumer_alert
  @consumer_alert
end

#containing_placesArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceContainingPlace>

List of places in which the current place is located. Corresponds to the JSON property containingPlaces



1192
1193
1194
# File 'lib/google/apis/places_v1/classes.rb', line 1192

def containing_places
  @containing_places
end

#curbside_pickupBoolean Also known as: curbside_pickup?

Specifies if the business supports curbside pickup. Corresponds to the JSON property curbsidePickup

Returns:

  • (Boolean)


1197
1198
1199
# File 'lib/google/apis/places_v1/classes.rb', line 1197

def curbside_pickup
  @curbside_pickup
end

#current_opening_hoursGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours

Information about business hour of the place. Corresponds to the JSON property currentOpeningHours



1203
1204
1205
# File 'lib/google/apis/places_v1/classes.rb', line 1203

def current_opening_hours
  @current_opening_hours
end

#current_secondary_opening_hoursArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours>

Contains an array of entries for the next seven days including information about secondary hours of a business. Secondary hours are different from a business's main hours. For example, a restaurant can specify drive through hours or delivery hours as its secondary hours. This field populates the type subfield, which draws from a predefined list of opening hours types (such as DRIVE_THROUGH, PICKUP, or TAKEOUT) based on the types of the place. This field includes the special_days subfield of all hours, set for dates that have exceptional hours. Corresponds to the JSON property currentSecondaryOpeningHours



1215
1216
1217
# File 'lib/google/apis/places_v1/classes.rb', line 1215

def current_secondary_opening_hours
  @current_secondary_opening_hours
end

#deliveryBoolean Also known as: delivery?

Specifies if the business supports delivery. Corresponds to the JSON property delivery

Returns:

  • (Boolean)


1220
1221
1222
# File 'lib/google/apis/places_v1/classes.rb', line 1220

def delivery
  @delivery
end

#dine_inBoolean Also known as: dine_in?

Specifies if the business supports indoor or outdoor seating options. Corresponds to the JSON property dineIn

Returns:

  • (Boolean)


1226
1227
1228
# File 'lib/google/apis/places_v1/classes.rb', line 1226

def dine_in
  @dine_in
end

#display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property displayName



1232
1233
1234
# File 'lib/google/apis/places_v1/classes.rb', line 1232

def display_name
  @display_name
end

#editorial_summaryGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property editorialSummary



1237
1238
1239
# File 'lib/google/apis/places_v1/classes.rb', line 1237

def editorial_summary
  @editorial_summary
end

#ev_charge_amenity_summaryGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceEvChargeAmenitySummary

The summary of amenities near the EV charging station. This only applies to places with type electric_vehicle_charging_station. The overview field is guaranteed to be provided while the other fields are optional. Corresponds to the JSON property evChargeAmenitySummary



1244
1245
1246
# File 'lib/google/apis/places_v1/classes.rb', line 1244

def ev_charge_amenity_summary
  @ev_charge_amenity_summary
end

#ev_charge_optionsGoogle::Apis::PlacesV1::GoogleMapsPlacesV1EvChargeOptions

Information about the EV Charge Station hosted in Place. Terminology follows https://afdc.energy.gov/fuels/electricity_infrastructure.html One port could charge one car at a time. One port has one or more connectors. One station has one or more ports. Corresponds to the JSON property evChargeOptions



1252
1253
1254
# File 'lib/google/apis/places_v1/classes.rb', line 1252

def ev_charge_options
  @ev_charge_options
end

#formatted_addressString

A full, human-readable address for this place. Corresponds to the JSON property formattedAddress

Returns:

  • (String)


1257
1258
1259
# File 'lib/google/apis/places_v1/classes.rb', line 1257

def formatted_address
  @formatted_address
end

#fuel_optionsGoogle::Apis::PlacesV1::GoogleMapsPlacesV1FuelOptions

The most recent information about fuel options in a gas station. This information is updated regularly. Corresponds to the JSON property fuelOptions



1263
1264
1265
# File 'lib/google/apis/places_v1/classes.rb', line 1263

def fuel_options
  @fuel_options
end

#generative_summaryGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGenerativeSummary

AI-generated summary of the place. Corresponds to the JSON property generativeSummary



1268
1269
1270
# File 'lib/google/apis/places_v1/classes.rb', line 1268

def generative_summary
  @generative_summary
end

#good_for_childrenBoolean Also known as: good_for_children?

Place is good for children. Corresponds to the JSON property goodForChildren

Returns:

  • (Boolean)


1273
1274
1275
# File 'lib/google/apis/places_v1/classes.rb', line 1273

def good_for_children
  @good_for_children
end

#good_for_groupsBoolean Also known as: good_for_groups?

Place accommodates groups. Corresponds to the JSON property goodForGroups

Returns:

  • (Boolean)


1279
1280
1281
# File 'lib/google/apis/places_v1/classes.rb', line 1279

def good_for_groups
  @good_for_groups
end

#good_for_watching_sportsBoolean Also known as: good_for_watching_sports?

Place is suitable for watching sports. Corresponds to the JSON property goodForWatchingSports

Returns:

  • (Boolean)


1285
1286
1287
# File 'lib/google/apis/places_v1/classes.rb', line 1285

def good_for_watching_sports
  @good_for_watching_sports
end

Links to trigger different Google Maps actions. Corresponds to the JSON property googleMapsLinks



1291
1292
1293
# File 'lib/google/apis/places_v1/classes.rb', line 1291

def google_maps_links
  @google_maps_links
end

#google_maps_type_labelGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property googleMapsTypeLabel



1296
1297
1298
# File 'lib/google/apis/places_v1/classes.rb', line 1296

def google_maps_type_label
  @google_maps_type_label
end

#google_maps_uriString

A URL providing more information about this place. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


1301
1302
1303
# File 'lib/google/apis/places_v1/classes.rb', line 1301

def google_maps_uri
  @google_maps_uri
end

#icon_background_colorString

Background color for icon_mask in hex format, e.g. #909CE1. Corresponds to the JSON property iconBackgroundColor

Returns:

  • (String)


1306
1307
1308
# File 'lib/google/apis/places_v1/classes.rb', line 1306

def icon_background_color
  @icon_background_color
end

#icon_mask_base_uriString

A truncated URL to an icon mask. User can access different icon type by appending type suffix to the end (eg, ".svg" or ".png"). Corresponds to the JSON property iconMaskBaseUri

Returns:

  • (String)


1312
1313
1314
# File 'lib/google/apis/places_v1/classes.rb', line 1312

def icon_mask_base_uri
  @icon_mask_base_uri
end

#idString

The unique identifier of a place. Corresponds to the JSON property id

Returns:

  • (String)


1317
1318
1319
# File 'lib/google/apis/places_v1/classes.rb', line 1317

def id
  @id
end

#international_phone_numberString

A human-readable phone number for the place, in international format. Corresponds to the JSON property internationalPhoneNumber

Returns:

  • (String)


1322
1323
1324
# File 'lib/google/apis/places_v1/classes.rb', line 1322

def international_phone_number
  @international_phone_number
end

#live_musicBoolean Also known as: live_music?

Place provides live music. Corresponds to the JSON property liveMusic

Returns:

  • (Boolean)


1327
1328
1329
# File 'lib/google/apis/places_v1/classes.rb', line 1327

def live_music
  @live_music
end

#locationGoogle::Apis::PlacesV1::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property location



1336
1337
1338
# File 'lib/google/apis/places_v1/classes.rb', line 1336

def location
  @location
end

Place has a children's menu. Corresponds to the JSON property menuForChildren

Returns:

  • (Boolean)


1341
1342
1343
# File 'lib/google/apis/places_v1/classes.rb', line 1341

def menu_for_children
  @menu_for_children
end

#moved_placeString

If this Place is permanently closed and has moved to a new Place, this field contains the new Place's resource name, in places/place_id`format. If this Place moved multiple times, this field will represent the first moved place. This field will not be populated if this Place has not moved. Corresponds to the JSON propertymovedPlace`

Returns:

  • (String)


1350
1351
1352
# File 'lib/google/apis/places_v1/classes.rb', line 1350

def moved_place
  @moved_place
end

#moved_place_idString

If this Place is permanently closed and has moved to a new Place, this field contains the new Place's place ID. If this Place moved multiple times, this field will represent the first moved Place. This field will not be populated if this Place has not moved. Corresponds to the JSON property movedPlaceId

Returns:

  • (String)


1358
1359
1360
# File 'lib/google/apis/places_v1/classes.rb', line 1358

def moved_place_id
  @moved_place_id
end

#nameString

This Place's resource name, in places/place_id`format. Can be used to look up the Place. Corresponds to the JSON propertyname`

Returns:

  • (String)


1364
1365
1366
# File 'lib/google/apis/places_v1/classes.rb', line 1364

def name
  @name
end

#national_phone_numberString

A human-readable phone number for the place, in national format. Corresponds to the JSON property nationalPhoneNumber

Returns:

  • (String)


1369
1370
1371
# File 'lib/google/apis/places_v1/classes.rb', line 1369

def national_phone_number
  @national_phone_number
end

#neighborhood_summaryGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceNeighborhoodSummary

A summary of points of interest near the place. Corresponds to the JSON property neighborhoodSummary



1374
1375
1376
# File 'lib/google/apis/places_v1/classes.rb', line 1374

def neighborhood_summary
  @neighborhood_summary
end

#opening_dateGoogle::Apis::PlacesV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property openingDate



1386
1387
1388
# File 'lib/google/apis/places_v1/classes.rb', line 1386

def opening_date
  @opening_date
end

#outdoor_seatingBoolean Also known as: outdoor_seating?

Place provides outdoor seating. Corresponds to the JSON property outdoorSeating

Returns:

  • (Boolean)


1391
1392
1393
# File 'lib/google/apis/places_v1/classes.rb', line 1391

def outdoor_seating
  @outdoor_seating
end

#parking_optionsGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceParkingOptions

Information about parking options for the place. A parking lot could support more than one option at the same time. Corresponds to the JSON property parkingOptions



1398
1399
1400
# File 'lib/google/apis/places_v1/classes.rb', line 1398

def parking_options
  @parking_options
end

#payment_optionsGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlacePaymentOptions

Payment options the place accepts. Corresponds to the JSON property paymentOptions



1403
1404
1405
# File 'lib/google/apis/places_v1/classes.rb', line 1403

def payment_options
  @payment_options
end

#photosArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1Photo>

Information (including references) about photos of this place. A maximum of 10 photos can be returned. Corresponds to the JSON property photos



1409
1410
1411
# File 'lib/google/apis/places_v1/classes.rb', line 1409

def photos
  @photos
end

#plus_codeGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlacePlusCode

Plus code (http://plus.codes) is a location reference with two formats: global code defining a 14mx14m (1/8000th of a degree) or smaller rectangle, and compound code, replacing the prefix with a reference location. Corresponds to the JSON property plusCode



1416
1417
1418
# File 'lib/google/apis/places_v1/classes.rb', line 1416

def plus_code
  @plus_code
end

#postal_addressGoogle::Apis::PlacesV1::GoogleTypePostalAddress

Represents a postal address, such as for postal delivery or payments addresses. With a postal address, a postal service can deliver items to a premise, P.O. box, or similar. A postal address is not intended to model geographical locations like roads, towns, or mountains. In typical usage, an address would be created by user input or from importing existing data, depending on the type of process. Advice on address input or editing: - Use an internationalization-ready address widget such as https://github.com/google/ libaddressinput. - Users should not be presented with UI elements for input or editing of fields outside countries where that field is used. For more guidance on how to use this schema, see: https://support.google.com/business/ answer/6397478. Corresponds to the JSON property postalAddress



1431
1432
1433
# File 'lib/google/apis/places_v1/classes.rb', line 1431

def postal_address
  @postal_address
end

#price_levelString

Price level of the place. Corresponds to the JSON property priceLevel

Returns:

  • (String)


1436
1437
1438
# File 'lib/google/apis/places_v1/classes.rb', line 1436

def price_level
  @price_level
end

#price_rangeGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PriceRange

The price range associated with a Place. end_price could be unset, which indicates a range without upper bound (e.g. "More than $100"). Corresponds to the JSON property priceRange



1442
1443
1444
# File 'lib/google/apis/places_v1/classes.rb', line 1442

def price_range
  @price_range
end

#primary_typeString

The primary type of the given result. This type must be one of the Places API supported types. For example, "restaurant", "cafe", "airport", etc. A place can only have a single primary type. For the complete list of possible values, see Table A and Table B at https://developers.google.com/maps/documentation/ places/web-service/place-types. The primary type may be missing if the place's primary type is not a supported type. When a primary type is present, it is always one of the types in the types field. Corresponds to the JSON property primaryType

Returns:

  • (String)


1453
1454
1455
# File 'lib/google/apis/places_v1/classes.rb', line 1453

def primary_type
  @primary_type
end

#primary_type_display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property primaryTypeDisplayName



1458
1459
1460
# File 'lib/google/apis/places_v1/classes.rb', line 1458

def primary_type_display_name
  @primary_type_display_name
end

#pure_service_area_businessBoolean Also known as: pure_service_area_business?

Indicates whether the place is a pure service area business. Pure service area business is a business that visits or delivers to customers directly but does not serve customers at their business address. For example, businesses like cleaning services or plumbers. Those businesses may not have a physical address or location on Google Maps. Corresponds to the JSON property pureServiceAreaBusiness

Returns:

  • (Boolean)


1467
1468
1469
# File 'lib/google/apis/places_v1/classes.rb', line 1467

def pure_service_area_business
  @pure_service_area_business
end

#ratingFloat

A rating between 1.0 and 5.0, based on user reviews of this place. Corresponds to the JSON property rating

Returns:

  • (Float)


1473
1474
1475
# File 'lib/google/apis/places_v1/classes.rb', line 1473

def rating
  @rating
end

#regular_opening_hoursGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours

Information about business hour of the place. Corresponds to the JSON property regularOpeningHours



1478
1479
1480
# File 'lib/google/apis/places_v1/classes.rb', line 1478

def regular_opening_hours
  @regular_opening_hours
end

#regular_secondary_opening_hoursArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHours>

Contains an array of entries for information about regular secondary hours of a business. Secondary hours are different from a business's main hours. For example, a restaurant can specify drive through hours or delivery hours as its secondary hours. This field populates the type subfield, which draws from a predefined list of opening hours types (such as DRIVE_THROUGH, PICKUP, or TAKEOUT) based on the types of the place. Corresponds to the JSON property regularSecondaryOpeningHours



1488
1489
1490
# File 'lib/google/apis/places_v1/classes.rb', line 1488

def regular_secondary_opening_hours
  @regular_secondary_opening_hours
end

#reservableBoolean Also known as: reservable?

Specifies if the place supports reservations. Corresponds to the JSON property reservable

Returns:

  • (Boolean)


1493
1494
1495
# File 'lib/google/apis/places_v1/classes.rb', line 1493

def reservable
  @reservable
end

#restroomBoolean Also known as: restroom?

Place has restroom. Corresponds to the JSON property restroom

Returns:

  • (Boolean)


1499
1500
1501
# File 'lib/google/apis/places_v1/classes.rb', line 1499

def restroom
  @restroom
end

#review_summaryGoogle::Apis::PlacesV1::GoogleMapsPlacesV1PlaceReviewSummary

AI-generated summary of the place using user reviews. Corresponds to the JSON property reviewSummary



1505
1506
1507
# File 'lib/google/apis/places_v1/classes.rb', line 1505

def review_summary
  @review_summary
end

#reviewsArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1Review>

List of reviews about this place, sorted by relevance. A maximum of 5 reviews can be returned. Corresponds to the JSON property reviews



1511
1512
1513
# File 'lib/google/apis/places_v1/classes.rb', line 1511

def reviews
  @reviews
end

#serves_beerBoolean Also known as: serves_beer?

Specifies if the place serves beer. Corresponds to the JSON property servesBeer

Returns:

  • (Boolean)


1516
1517
1518
# File 'lib/google/apis/places_v1/classes.rb', line 1516

def serves_beer
  @serves_beer
end

#serves_breakfastBoolean Also known as: serves_breakfast?

Specifies if the place serves breakfast. Corresponds to the JSON property servesBreakfast

Returns:

  • (Boolean)


1522
1523
1524
# File 'lib/google/apis/places_v1/classes.rb', line 1522

def serves_breakfast
  @serves_breakfast
end

#serves_brunchBoolean Also known as: serves_brunch?

Specifies if the place serves brunch. Corresponds to the JSON property servesBrunch

Returns:

  • (Boolean)


1528
1529
1530
# File 'lib/google/apis/places_v1/classes.rb', line 1528

def serves_brunch
  @serves_brunch
end

#serves_cocktailsBoolean Also known as: serves_cocktails?

Place serves cocktails. Corresponds to the JSON property servesCocktails

Returns:

  • (Boolean)


1534
1535
1536
# File 'lib/google/apis/places_v1/classes.rb', line 1534

def serves_cocktails
  @serves_cocktails
end

#serves_coffeeBoolean Also known as: serves_coffee?

Place serves coffee. Corresponds to the JSON property servesCoffee

Returns:

  • (Boolean)


1540
1541
1542
# File 'lib/google/apis/places_v1/classes.rb', line 1540

def serves_coffee
  @serves_coffee
end

#serves_dessertBoolean Also known as: serves_dessert?

Place serves dessert. Corresponds to the JSON property servesDessert

Returns:

  • (Boolean)


1546
1547
1548
# File 'lib/google/apis/places_v1/classes.rb', line 1546

def serves_dessert
  @serves_dessert
end

#serves_dinnerBoolean Also known as: serves_dinner?

Specifies if the place serves dinner. Corresponds to the JSON property servesDinner

Returns:

  • (Boolean)


1552
1553
1554
# File 'lib/google/apis/places_v1/classes.rb', line 1552

def serves_dinner
  @serves_dinner
end

#serves_lunchBoolean Also known as: serves_lunch?

Specifies if the place serves lunch. Corresponds to the JSON property servesLunch

Returns:

  • (Boolean)


1558
1559
1560
# File 'lib/google/apis/places_v1/classes.rb', line 1558

def serves_lunch
  @serves_lunch
end

#serves_vegetarian_foodBoolean Also known as: serves_vegetarian_food?

Specifies if the place serves vegetarian food. Corresponds to the JSON property servesVegetarianFood

Returns:

  • (Boolean)


1564
1565
1566
# File 'lib/google/apis/places_v1/classes.rb', line 1564

def serves_vegetarian_food
  @serves_vegetarian_food
end

#serves_wineBoolean Also known as: serves_wine?

Specifies if the place serves wine. Corresponds to the JSON property servesWine

Returns:

  • (Boolean)


1570
1571
1572
# File 'lib/google/apis/places_v1/classes.rb', line 1570

def serves_wine
  @serves_wine
end

#short_formatted_addressString

A short, human-readable address for this place. Corresponds to the JSON property shortFormattedAddress

Returns:

  • (String)


1576
1577
1578
# File 'lib/google/apis/places_v1/classes.rb', line 1576

def short_formatted_address
  @short_formatted_address
end

#sub_destinationsArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceSubDestination>

A list of sub-destinations related to the place. Corresponds to the JSON property subDestinations



1581
1582
1583
# File 'lib/google/apis/places_v1/classes.rb', line 1581

def sub_destinations
  @sub_destinations
end

#takeoutBoolean Also known as: takeout?

Specifies if the business supports takeout. Corresponds to the JSON property takeout

Returns:

  • (Boolean)


1586
1587
1588
# File 'lib/google/apis/places_v1/classes.rb', line 1586

def takeout
  @takeout
end

#time_zoneGoogle::Apis::PlacesV1::GoogleTypeTimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



1593
1594
1595
# File 'lib/google/apis/places_v1/classes.rb', line 1593

def time_zone
  @time_zone
end

#typesArray<String>

A set of type tags for this result. For example, "political" and "locality". For the complete list of possible values, see Table A and Table B at https:// developers.google.com/maps/documentation/places/web-service/place-types Corresponds to the JSON property types

Returns:

  • (Array<String>)


1600
1601
1602
# File 'lib/google/apis/places_v1/classes.rb', line 1600

def types
  @types
end

#user_rating_countFixnum

The total number of reviews (with or without text) for this place. Corresponds to the JSON property userRatingCount

Returns:

  • (Fixnum)


1605
1606
1607
# File 'lib/google/apis/places_v1/classes.rb', line 1605

def user_rating_count
  @user_rating_count
end

#utc_offset_minutesFixnum

Number of minutes this place's timezone is currently offset from UTC. This is expressed in minutes to support timezones that are offset by fractions of an hour, e.g. X hours and 15 minutes. Corresponds to the JSON property utcOffsetMinutes

Returns:

  • (Fixnum)


1612
1613
1614
# File 'lib/google/apis/places_v1/classes.rb', line 1612

def utc_offset_minutes
  @utc_offset_minutes
end

#viewportGoogle::Apis::PlacesV1::GoogleGeoTypeViewport

A latitude-longitude viewport, represented as two diagonally opposite low and high points. A viewport is considered a closed region, i.e. it includes its boundary. The latitude bounds must range between -90 to 90 degrees inclusive, and the longitude bounds must range between -180 to 180 degrees inclusive. Various cases include: - If low = high, the viewport consists of that single point. - If low.longitude > high.longitude, the longitude range is inverted (the viewport crosses the 180 degree longitude line). - If low.longitude = -180 degrees and high.longitude = 180 degrees, the viewport includes all longitudes. - If low.longitude = 180 degrees and high. longitude = -180 degrees, the longitude range is empty. - If low.latitude > high.latitude, the latitude range is empty. Both low and high must be populated, and the represented box cannot be empty (as specified by the definitions above). An empty viewport will result in an error. For example, this viewport fully encloses New York City: "low": "latitude": 40.477398, " longitude": -74.259087 , "high": "latitude": 40.91618, "longitude": -73. 70018 Corresponds to the JSON property viewport



1632
1633
1634
# File 'lib/google/apis/places_v1/classes.rb', line 1632

def viewport
  @viewport
end

#website_uriString

The authoritative website for this place, e.g. a business' homepage. Note that for places that are part of a chain (e.g. an IKEA store), this will usually be the website for the individual store, not the overall chain. Corresponds to the JSON property websiteUri

Returns:

  • (String)


1639
1640
1641
# File 'lib/google/apis/places_v1/classes.rb', line 1639

def website_uri
  @website_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
# File 'lib/google/apis/places_v1/classes.rb', line 1646

def update!(**args)
  @accessibility_options = args[:accessibility_options] if args.key?(:accessibility_options)
  @address_components = args[:address_components] if args.key?(:address_components)
  @address_descriptor = args[:address_descriptor] if args.key?(:address_descriptor)
  @adr_format_address = args[:adr_format_address] if args.key?(:adr_format_address)
  @allows_dogs = args[:allows_dogs] if args.key?(:allows_dogs)
  @attributions = args[:attributions] if args.key?(:attributions)
  @business_status = args[:business_status] if args.key?(:business_status)
  @consumer_alert = args[:consumer_alert] if args.key?(:consumer_alert)
  @containing_places = args[:containing_places] if args.key?(:containing_places)
  @curbside_pickup = args[:curbside_pickup] if args.key?(:curbside_pickup)
  @current_opening_hours = args[:current_opening_hours] if args.key?(:current_opening_hours)
  @current_secondary_opening_hours = args[:current_secondary_opening_hours] if args.key?(:current_secondary_opening_hours)
  @delivery = args[:delivery] if args.key?(:delivery)
  @dine_in = args[:dine_in] if args.key?(:dine_in)
  @display_name = args[:display_name] if args.key?(:display_name)
  @editorial_summary = args[:editorial_summary] if args.key?(:editorial_summary)
  @ev_charge_amenity_summary = args[:ev_charge_amenity_summary] if args.key?(:ev_charge_amenity_summary)
  @ev_charge_options = args[:ev_charge_options] if args.key?(:ev_charge_options)
  @formatted_address = args[:formatted_address] if args.key?(:formatted_address)
  @fuel_options = args[:fuel_options] if args.key?(:fuel_options)
  @generative_summary = args[:generative_summary] if args.key?(:generative_summary)
  @good_for_children = args[:good_for_children] if args.key?(:good_for_children)
  @good_for_groups = args[:good_for_groups] if args.key?(:good_for_groups)
  @good_for_watching_sports = args[:good_for_watching_sports] if args.key?(:good_for_watching_sports)
  @google_maps_links = args[:google_maps_links] if args.key?(:google_maps_links)
  @google_maps_type_label = args[:google_maps_type_label] if args.key?(:google_maps_type_label)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @icon_background_color = args[:icon_background_color] if args.key?(:icon_background_color)
  @icon_mask_base_uri = args[:icon_mask_base_uri] if args.key?(:icon_mask_base_uri)
  @id = args[:id] if args.key?(:id)
  @international_phone_number = args[:international_phone_number] if args.key?(:international_phone_number)
  @live_music = args[:live_music] if args.key?(:live_music)
  @location = args[:location] if args.key?(:location)
  @menu_for_children = args[:menu_for_children] if args.key?(:menu_for_children)
  @moved_place = args[:moved_place] if args.key?(:moved_place)
  @moved_place_id = args[:moved_place_id] if args.key?(:moved_place_id)
  @name = args[:name] if args.key?(:name)
  @national_phone_number = args[:national_phone_number] if args.key?(:national_phone_number)
  @neighborhood_summary = args[:neighborhood_summary] if args.key?(:neighborhood_summary)
  @opening_date = args[:opening_date] if args.key?(:opening_date)
  @outdoor_seating = args[:outdoor_seating] if args.key?(:outdoor_seating)
  @parking_options = args[:parking_options] if args.key?(:parking_options)
  @payment_options = args[:payment_options] if args.key?(:payment_options)
  @photos = args[:photos] if args.key?(:photos)
  @plus_code = args[:plus_code] if args.key?(:plus_code)
  @postal_address = args[:postal_address] if args.key?(:postal_address)
  @price_level = args[:price_level] if args.key?(:price_level)
  @price_range = args[:price_range] if args.key?(:price_range)
  @primary_type = args[:primary_type] if args.key?(:primary_type)
  @primary_type_display_name = args[:primary_type_display_name] if args.key?(:primary_type_display_name)
  @pure_service_area_business = args[:pure_service_area_business] if args.key?(:pure_service_area_business)
  @rating = args[:rating] if args.key?(:rating)
  @regular_opening_hours = args[:regular_opening_hours] if args.key?(:regular_opening_hours)
  @regular_secondary_opening_hours = args[:regular_secondary_opening_hours] if args.key?(:regular_secondary_opening_hours)
  @reservable = args[:reservable] if args.key?(:reservable)
  @restroom = args[:restroom] if args.key?(:restroom)
  @review_summary = args[:review_summary] if args.key?(:review_summary)
  @reviews = args[:reviews] if args.key?(:reviews)
  @serves_beer = args[:serves_beer] if args.key?(:serves_beer)
  @serves_breakfast = args[:serves_breakfast] if args.key?(:serves_breakfast)
  @serves_brunch = args[:serves_brunch] if args.key?(:serves_brunch)
  @serves_cocktails = args[:serves_cocktails] if args.key?(:serves_cocktails)
  @serves_coffee = args[:serves_coffee] if args.key?(:serves_coffee)
  @serves_dessert = args[:serves_dessert] if args.key?(:serves_dessert)
  @serves_dinner = args[:serves_dinner] if args.key?(:serves_dinner)
  @serves_lunch = args[:serves_lunch] if args.key?(:serves_lunch)
  @serves_vegetarian_food = args[:serves_vegetarian_food] if args.key?(:serves_vegetarian_food)
  @serves_wine = args[:serves_wine] if args.key?(:serves_wine)
  @short_formatted_address = args[:short_formatted_address] if args.key?(:short_formatted_address)
  @sub_destinations = args[:sub_destinations] if args.key?(:sub_destinations)
  @takeout = args[:takeout] if args.key?(:takeout)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @types = args[:types] if args.key?(:types)
  @user_rating_count = args[:user_rating_count] if args.key?(:user_rating_count)
  @utc_offset_minutes = args[:utc_offset_minutes] if args.key?(:utc_offset_minutes)
  @viewport = args[:viewport] if args.key?(:viewport)
  @website_uri = args[:website_uri] if args.key?(:website_uri)
end