Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlertDetails
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlertDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
The details of the consumer alert message.
Instance Attribute Summary collapse
-
#about_link ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlertDetailsLink
The link to show together with the description to provide more information.
-
#description ⇒ String
The description of the consumer alert message.
-
#title ⇒ String
The title to show together with the description.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceConsumerAlertDetails
constructor
A new instance of GoogleMapsPlacesV1PlaceConsumerAlertDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceConsumerAlertDetails
Returns a new instance of GoogleMapsPlacesV1PlaceConsumerAlertDetails.
1887 1888 1889 |
# File 'lib/google/apis/places_v1/classes.rb', line 1887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#about_link ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceConsumerAlertDetailsLink
The link to show together with the description to provide more information.
Corresponds to the JSON property aboutLink
1875 1876 1877 |
# File 'lib/google/apis/places_v1/classes.rb', line 1875 def about_link @about_link end |
#description ⇒ String
The description of the consumer alert message.
Corresponds to the JSON property description
1880 1881 1882 |
# File 'lib/google/apis/places_v1/classes.rb', line 1880 def description @description end |
#title ⇒ String
The title to show together with the description.
Corresponds to the JSON property title
1885 1886 1887 |
# File 'lib/google/apis/places_v1/classes.rb', line 1885 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1892 1893 1894 1895 1896 |
# File 'lib/google/apis/places_v1/classes.rb', line 1892 def update!(**args) @about_link = args[:about_link] if args.key?(:about_link) @description = args[:description] if args.key?(:description) @title = args[:title] if args.key?(:title) end |