Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceContainingPlace

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Info about the place in which this place is located.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceContainingPlace

Returns a new instance of GoogleMapsPlacesV1PlaceContainingPlace.



1938
1939
1940
# File 'lib/google/apis/places_v1/classes.rb', line 1938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The place id of the place in which this place is located. Corresponds to the JSON property id

Returns:

  • (String)


1931
1932
1933
# File 'lib/google/apis/places_v1/classes.rb', line 1931

def id
  @id
end

#nameString

The resource name of the place in which this place is located. Corresponds to the JSON property name

Returns:

  • (String)


1936
1937
1938
# File 'lib/google/apis/places_v1/classes.rb', line 1936

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1943
1944
1945
1946
# File 'lib/google/apis/places_v1/classes.rb', line 1943

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
end