Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceEvChargeAmenitySummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

The summary of amenities near the EV charging station. This only applies to places with type electric_vehicle_charging_station. The overview field is guaranteed to be provided while the other fields are optional.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceEvChargeAmenitySummary

Returns a new instance of GoogleMapsPlacesV1PlaceEvChargeAmenitySummary.



1979
1980
1981
# File 'lib/google/apis/places_v1/classes.rb', line 1979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#coffeeGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock

A block of content that can be served individually. Corresponds to the JSON property coffee



1952
1953
1954
# File 'lib/google/apis/places_v1/classes.rb', line 1952

def coffee
  @coffee
end

#disclosure_textGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property disclosureText



1957
1958
1959
# File 'lib/google/apis/places_v1/classes.rb', line 1957

def disclosure_text
  @disclosure_text
end

#flag_content_uriString

A link where users can flag a problem with the summary. Corresponds to the JSON property flagContentUri

Returns:

  • (String)


1962
1963
1964
# File 'lib/google/apis/places_v1/classes.rb', line 1962

def flag_content_uri
  @flag_content_uri
end

#overviewGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock

A block of content that can be served individually. Corresponds to the JSON property overview



1967
1968
1969
# File 'lib/google/apis/places_v1/classes.rb', line 1967

def overview
  @overview
end

#restaurantGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock

A block of content that can be served individually. Corresponds to the JSON property restaurant



1972
1973
1974
# File 'lib/google/apis/places_v1/classes.rb', line 1972

def restaurant
  @restaurant
end

#storeGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock

A block of content that can be served individually. Corresponds to the JSON property store



1977
1978
1979
# File 'lib/google/apis/places_v1/classes.rb', line 1977

def store
  @store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1984
1985
1986
1987
1988
1989
1990
1991
# File 'lib/google/apis/places_v1/classes.rb', line 1984

def update!(**args)
  @coffee = args[:coffee] if args.key?(:coffee)
  @disclosure_text = args[:disclosure_text] if args.key?(:disclosure_text)
  @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri)
  @overview = args[:overview] if args.key?(:overview)
  @restaurant = args[:restaurant] if args.key?(:restaurant)
  @store = args[:store] if args.key?(:store)
end