Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGenerativeSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

AI-generated summary of the place.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceGenerativeSummary

Returns a new instance of GoogleMapsPlacesV1PlaceGenerativeSummary.



2013
2014
2015
# File 'lib/google/apis/places_v1/classes.rb', line 2013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disclosure_textGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property disclosureText



2001
2002
2003
# File 'lib/google/apis/places_v1/classes.rb', line 2001

def disclosure_text
  @disclosure_text
end

#overviewGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property overview



2006
2007
2008
# File 'lib/google/apis/places_v1/classes.rb', line 2006

def overview
  @overview
end

#overview_flag_content_uriString

A link where users can flag a problem with the overview summary. Corresponds to the JSON property overviewFlagContentUri

Returns:

  • (String)


2011
2012
2013
# File 'lib/google/apis/places_v1/classes.rb', line 2011

def overview_flag_content_uri
  @overview_flag_content_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2018
2019
2020
2021
2022
# File 'lib/google/apis/places_v1/classes.rb', line 2018

def update!(**args)
  @disclosure_text = args[:disclosure_text] if args.key?(:disclosure_text)
  @overview = args[:overview] if args.key?(:overview)
  @overview_flag_content_uri = args[:overview_flag_content_uri] if args.key?(:overview_flag_content_uri)
end