Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGenerativeSummary
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGenerativeSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
AI-generated summary of the place.
Instance Attribute Summary collapse
-
#disclosure_text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#overview ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#overview_flag_content_uri ⇒ String
A link where users can flag a problem with the overview summary.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceGenerativeSummary
constructor
A new instance of GoogleMapsPlacesV1PlaceGenerativeSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceGenerativeSummary
Returns a new instance of GoogleMapsPlacesV1PlaceGenerativeSummary.
2025 2026 2027 |
# File 'lib/google/apis/places_v1/classes.rb', line 2025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disclosure_text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property disclosureText
2013 2014 2015 |
# File 'lib/google/apis/places_v1/classes.rb', line 2013 def disclosure_text @disclosure_text end |
#overview ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property overview
2018 2019 2020 |
# File 'lib/google/apis/places_v1/classes.rb', line 2018 def overview @overview end |
#overview_flag_content_uri ⇒ String
A link where users can flag a problem with the overview summary.
Corresponds to the JSON property overviewFlagContentUri
2023 2024 2025 |
# File 'lib/google/apis/places_v1/classes.rb', line 2023 def overview_flag_content_uri @overview_flag_content_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2030 2031 2032 2033 2034 |
# File 'lib/google/apis/places_v1/classes.rb', line 2030 def update!(**args) @disclosure_text = args[:disclosure_text] if args.key?(:disclosure_text) @overview = args[:overview] if args.key?(:overview) @overview_flag_content_uri = args[:overview_flag_content_uri] if args.key?(:overview_flag_content_uri) end |