Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGenerativeSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

AI-generated summary of the place.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceGenerativeSummary

Returns a new instance of GoogleMapsPlacesV1PlaceGenerativeSummary.



2019
2020
2021
# File 'lib/google/apis/places_v1/classes.rb', line 2019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disclosure_textGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property disclosureText



2007
2008
2009
# File 'lib/google/apis/places_v1/classes.rb', line 2007

def disclosure_text
  @disclosure_text
end

#overviewGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property overview



2012
2013
2014
# File 'lib/google/apis/places_v1/classes.rb', line 2012

def overview
  @overview
end

#overview_flag_content_uriString

A link where users can flag a problem with the overview summary. Corresponds to the JSON property overviewFlagContentUri

Returns:

  • (String)


2017
2018
2019
# File 'lib/google/apis/places_v1/classes.rb', line 2017

def overview_flag_content_uri
  @overview_flag_content_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2024
2025
2026
2027
2028
# File 'lib/google/apis/places_v1/classes.rb', line 2024

def update!(**args)
  @disclosure_text = args[:disclosure_text] if args.key?(:disclosure_text)
  @overview = args[:overview] if args.key?(:overview)
  @overview_flag_content_uri = args[:overview_flag_content_uri] if args.key?(:overview_flag_content_uri)
end