Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGoogleMapsLinks
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGoogleMapsLinks
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Links to trigger different Google Maps actions.
Instance Attribute Summary collapse
-
#directions_uri ⇒ String
A link to show the directions to the place.
-
#photos_uri ⇒ String
A link to show photos of this place on Google Maps.
-
#place_uri ⇒ String
A link to show this place.
-
#reviews_uri ⇒ String
A link to show reviews of this place on Google Maps.
-
#write_a_review_uri ⇒ String
A link to write a review for this place on Google Maps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceGoogleMapsLinks
constructor
A new instance of GoogleMapsPlacesV1PlaceGoogleMapsLinks.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceGoogleMapsLinks
Returns a new instance of GoogleMapsPlacesV1PlaceGoogleMapsLinks.
2055 2056 2057 |
# File 'lib/google/apis/places_v1/classes.rb', line 2055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#directions_uri ⇒ String
A link to show the directions to the place. The link only populates the
destination location and uses the default travel mode DRIVE.
Corresponds to the JSON property directionsUri
2033 2034 2035 |
# File 'lib/google/apis/places_v1/classes.rb', line 2033 def directions_uri @directions_uri end |
#photos_uri ⇒ String
A link to show photos of this place on Google Maps.
Corresponds to the JSON property photosUri
2038 2039 2040 |
# File 'lib/google/apis/places_v1/classes.rb', line 2038 def photos_uri @photos_uri end |
#place_uri ⇒ String
A link to show this place.
Corresponds to the JSON property placeUri
2043 2044 2045 |
# File 'lib/google/apis/places_v1/classes.rb', line 2043 def place_uri @place_uri end |
#reviews_uri ⇒ String
A link to show reviews of this place on Google Maps.
Corresponds to the JSON property reviewsUri
2048 2049 2050 |
# File 'lib/google/apis/places_v1/classes.rb', line 2048 def reviews_uri @reviews_uri end |
#write_a_review_uri ⇒ String
A link to write a review for this place on Google Maps.
Corresponds to the JSON property writeAReviewUri
2053 2054 2055 |
# File 'lib/google/apis/places_v1/classes.rb', line 2053 def write_a_review_uri @write_a_review_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2060 2061 2062 2063 2064 2065 2066 |
# File 'lib/google/apis/places_v1/classes.rb', line 2060 def update!(**args) @directions_uri = args[:directions_uri] if args.key?(:directions_uri) @photos_uri = args[:photos_uri] if args.key?(:photos_uri) @place_uri = args[:place_uri] if args.key?(:place_uri) @reviews_uri = args[:reviews_uri] if args.key?(:reviews_uri) @write_a_review_uri = args[:write_a_review_uri] if args.key?(:write_a_review_uri) end |