Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceGoogleMapsLinks

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Links to trigger different Google Maps actions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceGoogleMapsLinks

Returns a new instance of GoogleMapsPlacesV1PlaceGoogleMapsLinks.



2061
2062
2063
# File 'lib/google/apis/places_v1/classes.rb', line 2061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#directions_uriString

A link to show the directions to the place. The link only populates the destination location and uses the default travel mode DRIVE. Corresponds to the JSON property directionsUri

Returns:

  • (String)


2039
2040
2041
# File 'lib/google/apis/places_v1/classes.rb', line 2039

def directions_uri
  @directions_uri
end

#photos_uriString

A link to show photos of this place on Google Maps. Corresponds to the JSON property photosUri

Returns:

  • (String)


2044
2045
2046
# File 'lib/google/apis/places_v1/classes.rb', line 2044

def photos_uri
  @photos_uri
end

#place_uriString

A link to show this place. Corresponds to the JSON property placeUri

Returns:

  • (String)


2049
2050
2051
# File 'lib/google/apis/places_v1/classes.rb', line 2049

def place_uri
  @place_uri
end

#reviews_uriString

A link to show reviews of this place on Google Maps. Corresponds to the JSON property reviewsUri

Returns:

  • (String)


2054
2055
2056
# File 'lib/google/apis/places_v1/classes.rb', line 2054

def reviews_uri
  @reviews_uri
end

#write_a_review_uriString

A link to write a review for this place on Google Maps. Corresponds to the JSON property writeAReviewUri

Returns:

  • (String)


2059
2060
2061
# File 'lib/google/apis/places_v1/classes.rb', line 2059

def write_a_review_uri
  @write_a_review_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2066
2067
2068
2069
2070
2071
2072
# File 'lib/google/apis/places_v1/classes.rb', line 2066

def update!(**args)
  @directions_uri = args[:directions_uri] if args.key?(:directions_uri)
  @photos_uri = args[:photos_uri] if args.key?(:photos_uri)
  @place_uri = args[:place_uri] if args.key?(:place_uri)
  @reviews_uri = args[:reviews_uri] if args.key?(:reviews_uri)
  @write_a_review_uri = args[:write_a_review_uri] if args.key?(:write_a_review_uri)
end