Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceNeighborhoodSummary
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceNeighborhoodSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
A summary of points of interest near the place.
Instance Attribute Summary collapse
-
#description ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock
A block of content that can be served individually.
-
#disclosure_text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#flag_content_uri ⇒ String
A link where users can flag a problem with the summary.
-
#overview ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock
A block of content that can be served individually.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceNeighborhoodSummary
constructor
A new instance of GoogleMapsPlacesV1PlaceNeighborhoodSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceNeighborhoodSummary
Returns a new instance of GoogleMapsPlacesV1PlaceNeighborhoodSummary.
2182 2183 2184 |
# File 'lib/google/apis/places_v1/classes.rb', line 2182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock
A block of content that can be served individually.
Corresponds to the JSON property description
2165 2166 2167 |
# File 'lib/google/apis/places_v1/classes.rb', line 2165 def description @description end |
#disclosure_text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property disclosureText
2170 2171 2172 |
# File 'lib/google/apis/places_v1/classes.rb', line 2170 def disclosure_text @disclosure_text end |
#flag_content_uri ⇒ String
A link where users can flag a problem with the summary.
Corresponds to the JSON property flagContentUri
2175 2176 2177 |
# File 'lib/google/apis/places_v1/classes.rb', line 2175 def flag_content_uri @flag_content_uri end |
#overview ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock
A block of content that can be served individually.
Corresponds to the JSON property overview
2180 2181 2182 |
# File 'lib/google/apis/places_v1/classes.rb', line 2180 def overview @overview end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2187 2188 2189 2190 2191 2192 |
# File 'lib/google/apis/places_v1/classes.rb', line 2187 def update!(**args) @description = args[:description] if args.key?(:description) @disclosure_text = args[:disclosure_text] if args.key?(:disclosure_text) @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri) @overview = args[:overview] if args.key?(:overview) end |