Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceNeighborhoodSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

A summary of points of interest near the place.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceNeighborhoodSummary

Returns a new instance of GoogleMapsPlacesV1PlaceNeighborhoodSummary.



2099
2100
2101
# File 'lib/google/apis/places_v1/classes.rb', line 2099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock

A block of content that can be served individually. Corresponds to the JSON property description



2082
2083
2084
# File 'lib/google/apis/places_v1/classes.rb', line 2082

def description
  @description
end

#disclosure_textGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property disclosureText



2087
2088
2089
# File 'lib/google/apis/places_v1/classes.rb', line 2087

def disclosure_text
  @disclosure_text
end

#flag_content_uriString

A link where users can flag a problem with the summary. Corresponds to the JSON property flagContentUri

Returns:

  • (String)


2092
2093
2094
# File 'lib/google/apis/places_v1/classes.rb', line 2092

def flag_content_uri
  @flag_content_uri
end

#overviewGoogle::Apis::PlacesV1::GoogleMapsPlacesV1ContentBlock

A block of content that can be served individually. Corresponds to the JSON property overview



2097
2098
2099
# File 'lib/google/apis/places_v1/classes.rb', line 2097

def overview
  @overview
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2104
2105
2106
2107
2108
2109
# File 'lib/google/apis/places_v1/classes.rb', line 2104

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disclosure_text = args[:disclosure_text] if args.key?(:disclosure_text)
  @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri)
  @overview = args[:overview] if args.key?(:overview)
end