Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Status changing points.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint

Returns a new instance of GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint.



2265
2266
2267
# File 'lib/google/apis/places_v1/classes.rb', line 2265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dateGoogle::Apis::PlacesV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



2238
2239
2240
# File 'lib/google/apis/places_v1/classes.rb', line 2238

def date
  @date
end

#dayFixnum

A day of the week, as an integer in the range 0-6. 0 is Sunday, 1 is Monday, etc. Corresponds to the JSON property day

Returns:

  • (Fixnum)


2244
2245
2246
# File 'lib/google/apis/places_v1/classes.rb', line 2244

def day
  @day
end

#hourFixnum

The hour in 24 hour format. Ranges from 0 to 23. Corresponds to the JSON property hour

Returns:

  • (Fixnum)


2249
2250
2251
# File 'lib/google/apis/places_v1/classes.rb', line 2249

def hour
  @hour
end

#minuteFixnum

The minute. Ranges from 0 to 59. Corresponds to the JSON property minute

Returns:

  • (Fixnum)


2254
2255
2256
# File 'lib/google/apis/places_v1/classes.rb', line 2254

def minute
  @minute
end

#truncatedBoolean Also known as: truncated?

Whether or not this endpoint was truncated. Truncation occurs when the real hours are outside the times we are willing to return hours between, so we truncate the hours back to these boundaries. This ensures that at most 24 * 7 hours from midnight of the day of the request are returned. Corresponds to the JSON property truncated

Returns:

  • (Boolean)


2262
2263
2264
# File 'lib/google/apis/places_v1/classes.rb', line 2262

def truncated
  @truncated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2270
2271
2272
2273
2274
2275
2276
# File 'lib/google/apis/places_v1/classes.rb', line 2270

def update!(**args)
  @date = args[:date] if args.key?(:date)
  @day = args[:day] if args.key?(:day)
  @hour = args[:hour] if args.key?(:hour)
  @minute = args[:minute] if args.key?(:minute)
  @truncated = args[:truncated] if args.key?(:truncated)
end