Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Status changing points.
Instance Attribute Summary collapse
-
#date ⇒ Google::Apis::PlacesV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#day ⇒ Fixnum
A day of the week, as an integer in the range 0-6.
-
#hour ⇒ Fixnum
The hour in 24 hour format.
-
#minute ⇒ Fixnum
The minute.
-
#truncated ⇒ Boolean
(also: #truncated?)
Whether or not this endpoint was truncated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint
constructor
A new instance of GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint
Returns a new instance of GoogleMapsPlacesV1PlaceOpeningHoursPeriodPoint.
2259 2260 2261 |
# File 'lib/google/apis/places_v1/classes.rb', line 2259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date ⇒ Google::Apis::PlacesV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property date
2232 2233 2234 |
# File 'lib/google/apis/places_v1/classes.rb', line 2232 def date @date end |
#day ⇒ Fixnum
A day of the week, as an integer in the range 0-6. 0 is Sunday, 1 is Monday,
etc.
Corresponds to the JSON property day
2238 2239 2240 |
# File 'lib/google/apis/places_v1/classes.rb', line 2238 def day @day end |
#hour ⇒ Fixnum
The hour in 24 hour format. Ranges from 0 to 23.
Corresponds to the JSON property hour
2243 2244 2245 |
# File 'lib/google/apis/places_v1/classes.rb', line 2243 def hour @hour end |
#minute ⇒ Fixnum
The minute. Ranges from 0 to 59.
Corresponds to the JSON property minute
2248 2249 2250 |
# File 'lib/google/apis/places_v1/classes.rb', line 2248 def minute @minute end |
#truncated ⇒ Boolean Also known as: truncated?
Whether or not this endpoint was truncated. Truncation occurs when the real
hours are outside the times we are willing to return hours between, so we
truncate the hours back to these boundaries. This ensures that at most 24 * 7
hours from midnight of the day of the request are returned.
Corresponds to the JSON property truncated
2256 2257 2258 |
# File 'lib/google/apis/places_v1/classes.rb', line 2256 def truncated @truncated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/google/apis/places_v1/classes.rb', line 2264 def update!(**args) @date = args[:date] if args.key?(:date) @day = args[:day] if args.key?(:day) @hour = args[:hour] if args.key?(:hour) @minute = args[:minute] if args.key?(:minute) @truncated = args[:truncated] if args.key?(:truncated) end |