Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceReviewSummary
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceReviewSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
AI-generated summary of the place using user reviews.
Instance Attribute Summary collapse
-
#disclosure_text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#flag_content_uri ⇒ String
A link where users can flag a problem with the summary.
-
#reviews_uri ⇒ String
A link to show reviews of this place on Google Maps.
-
#text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceReviewSummary
constructor
A new instance of GoogleMapsPlacesV1PlaceReviewSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceReviewSummary
Returns a new instance of GoogleMapsPlacesV1PlaceReviewSummary.
2460 2461 2462 |
# File 'lib/google/apis/places_v1/classes.rb', line 2460 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disclosure_text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property disclosureText
2443 2444 2445 |
# File 'lib/google/apis/places_v1/classes.rb', line 2443 def disclosure_text @disclosure_text end |
#flag_content_uri ⇒ String
A link where users can flag a problem with the summary.
Corresponds to the JSON property flagContentUri
2448 2449 2450 |
# File 'lib/google/apis/places_v1/classes.rb', line 2448 def flag_content_uri @flag_content_uri end |
#reviews_uri ⇒ String
A link to show reviews of this place on Google Maps.
Corresponds to the JSON property reviewsUri
2453 2454 2455 |
# File 'lib/google/apis/places_v1/classes.rb', line 2453 def reviews_uri @reviews_uri end |
#text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property text
2458 2459 2460 |
# File 'lib/google/apis/places_v1/classes.rb', line 2458 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2465 2466 2467 2468 2469 2470 |
# File 'lib/google/apis/places_v1/classes.rb', line 2465 def update!(**args) @disclosure_text = args[:disclosure_text] if args.key?(:disclosure_text) @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri) @reviews_uri = args[:reviews_uri] if args.key?(:reviews_uri) @text = args[:text] if args.key?(:text) end |