Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceSubDestination
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1PlaceSubDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Sub-destinations are specific places associated with a main place. These provide more specific destinations for users who are searching within a large or complex place, like an airport, national park, university, or stadium. For example, sub-destinations at an airport might include associated terminals and parking lots. Sub-destinations return the place ID and place resource name, which can be used in subsequent Place Details (New) requests to fetch richer details, including the sub-destination's display name and location.
Instance Attribute Summary collapse
-
#id ⇒ String
The place id of the sub-destination.
-
#name ⇒ String
The resource name of the sub-destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceSubDestination
constructor
A new instance of GoogleMapsPlacesV1PlaceSubDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1PlaceSubDestination
Returns a new instance of GoogleMapsPlacesV1PlaceSubDestination.
2493 2494 2495 |
# File 'lib/google/apis/places_v1/classes.rb', line 2493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The place id of the sub-destination.
Corresponds to the JSON property id
2486 2487 2488 |
# File 'lib/google/apis/places_v1/classes.rb', line 2486 def id @id end |
#name ⇒ String
The resource name of the sub-destination.
Corresponds to the JSON property name
2491 2492 2493 |
# File 'lib/google/apis/places_v1/classes.rb', line 2491 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2498 2499 2500 2501 |
# File 'lib/google/apis/places_v1/classes.rb', line 2498 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |