Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1PriceRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

The price range associated with a Place. end_price could be unset, which indicates a range without upper bound (e.g. "More than $100").

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1PriceRange

Returns a new instance of GoogleMapsPlacesV1PriceRange.



2540
2541
2542
# File 'lib/google/apis/places_v1/classes.rb', line 2540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_priceGoogle::Apis::PlacesV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property endPrice



2533
2534
2535
# File 'lib/google/apis/places_v1/classes.rb', line 2533

def end_price
  @end_price
end

#start_priceGoogle::Apis::PlacesV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property startPrice



2538
2539
2540
# File 'lib/google/apis/places_v1/classes.rb', line 2538

def start_price
  @start_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2545
2546
2547
2548
# File 'lib/google/apis/places_v1/classes.rb', line 2545

def update!(**args)
  @end_price = args[:end_price] if args.key?(:end_price)
  @start_price = args[:start_price] if args.key?(:start_price)
end