Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1Review

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Information about a review of a place.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1Review

Returns a new instance of GoogleMapsPlacesV1Review.



2621
2622
2623
# File 'lib/google/apis/places_v1/classes.rb', line 2621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#author_attributionGoogle::Apis::PlacesV1::GoogleMapsPlacesV1AuthorAttribution

Information about the author of the UGC data. Used in Photo, and Review. Corresponds to the JSON property authorAttribution



2564
2565
2566
# File 'lib/google/apis/places_v1/classes.rb', line 2564

def author_attribution
  @author_attribution
end

#flag_content_uriString

A link where users can flag a problem with the review. Corresponds to the JSON property flagContentUri

Returns:

  • (String)


2569
2570
2571
# File 'lib/google/apis/places_v1/classes.rb', line 2569

def flag_content_uri
  @flag_content_uri
end

#google_maps_uriString

A link to show the review on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


2574
2575
2576
# File 'lib/google/apis/places_v1/classes.rb', line 2574

def google_maps_uri
  @google_maps_uri
end

#nameString

A reference representing this place review which may be used to look up this place review again (also called the API "resource" name: places/place_id/ reviews/review`). Corresponds to the JSON propertyname`

Returns:

  • (String)


2581
2582
2583
# File 'lib/google/apis/places_v1/classes.rb', line 2581

def name
  @name
end

#original_textGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property originalText



2586
2587
2588
# File 'lib/google/apis/places_v1/classes.rb', line 2586

def original_text
  @original_text
end

#publish_timeString

Timestamp for the review. Corresponds to the JSON property publishTime

Returns:

  • (String)


2591
2592
2593
# File 'lib/google/apis/places_v1/classes.rb', line 2591

def publish_time
  @publish_time
end

#ratingFloat

A number between 1.0 and 5.0, also called the number of stars. Corresponds to the JSON property rating

Returns:

  • (Float)


2596
2597
2598
# File 'lib/google/apis/places_v1/classes.rb', line 2596

def rating
  @rating
end

#relative_publish_time_descriptionString

A string of formatted recent time, expressing the review time relative to the current time in a form appropriate for the language and country. Corresponds to the JSON property relativePublishTimeDescription

Returns:

  • (String)


2602
2603
2604
# File 'lib/google/apis/places_v1/classes.rb', line 2602

def relative_publish_time_description
  @relative_publish_time_description
end

#textGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property text



2607
2608
2609
# File 'lib/google/apis/places_v1/classes.rb', line 2607

def text
  @text
end

#visit_dateGoogle::Apis::PlacesV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property visitDate



2619
2620
2621
# File 'lib/google/apis/places_v1/classes.rb', line 2619

def visit_date
  @visit_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
# File 'lib/google/apis/places_v1/classes.rb', line 2626

def update!(**args)
  @author_attribution = args[:author_attribution] if args.key?(:author_attribution)
  @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @name = args[:name] if args.key?(:name)
  @original_text = args[:original_text] if args.key?(:original_text)
  @publish_time = args[:publish_time] if args.key?(:publish_time)
  @rating = args[:rating] if args.key?(:rating)
  @relative_publish_time_description = args[:relative_publish_time_description] if args.key?(:relative_publish_time_description)
  @text = args[:text] if args.key?(:text)
  @visit_date = args[:visit_date] if args.key?(:visit_date)
end