Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1RouteModifiers
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1RouteModifiers
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Encapsulates a set of optional conditions to satisfy when calculating the routes.
Instance Attribute Summary collapse
-
#avoid_ferries ⇒ Boolean
(also: #avoid_ferries?)
Optional.
-
#avoid_highways ⇒ Boolean
(also: #avoid_highways?)
Optional.
-
#avoid_indoor ⇒ Boolean
(also: #avoid_indoor?)
Optional.
-
#avoid_tolls ⇒ Boolean
(also: #avoid_tolls?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1RouteModifiers
constructor
A new instance of GoogleMapsPlacesV1RouteModifiers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1RouteModifiers
Returns a new instance of GoogleMapsPlacesV1RouteModifiers.
2683 2684 2685 |
# File 'lib/google/apis/places_v1/classes.rb', line 2683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avoid_ferries ⇒ Boolean Also known as: avoid_ferries?
Optional. When set to true, avoids ferries where reasonable, giving preference
to routes not containing ferries. Applies only to the DRIVE and TWO_WHEELER
TravelMode.
Corresponds to the JSON property avoidFerries
2656 2657 2658 |
# File 'lib/google/apis/places_v1/classes.rb', line 2656 def avoid_ferries @avoid_ferries end |
#avoid_highways ⇒ Boolean Also known as: avoid_highways?
Optional. When set to true, avoids highways where reasonable, giving
preference to routes not containing highways. Applies only to the DRIVE and
TWO_WHEELER TravelMode.
Corresponds to the JSON property avoidHighways
2664 2665 2666 |
# File 'lib/google/apis/places_v1/classes.rb', line 2664 def avoid_highways @avoid_highways end |
#avoid_indoor ⇒ Boolean Also known as: avoid_indoor?
Optional. When set to true, avoids navigating indoors where reasonable, giving
preference to routes not containing indoor navigation. Applies only to the
WALK TravelMode.
Corresponds to the JSON property avoidIndoor
2672 2673 2674 |
# File 'lib/google/apis/places_v1/classes.rb', line 2672 def avoid_indoor @avoid_indoor end |
#avoid_tolls ⇒ Boolean Also known as: avoid_tolls?
Optional. When set to true, avoids toll roads where reasonable, giving
preference to routes not containing toll roads. Applies only to the DRIVE
and TWO_WHEELER TravelMode.
Corresponds to the JSON property avoidTolls
2680 2681 2682 |
# File 'lib/google/apis/places_v1/classes.rb', line 2680 def avoid_tolls @avoid_tolls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2688 2689 2690 2691 2692 2693 |
# File 'lib/google/apis/places_v1/classes.rb', line 2688 def update!(**args) @avoid_ferries = args[:avoid_ferries] if args.key?(:avoid_ferries) @avoid_highways = args[:avoid_highways] if args.key?(:avoid_highways) @avoid_indoor = args[:avoid_indoor] if args.key?(:avoid_indoor) @avoid_tolls = args[:avoid_tolls] if args.key?(:avoid_tolls) end |