Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1RouteModifiers

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Encapsulates a set of optional conditions to satisfy when calculating the routes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1RouteModifiers

Returns a new instance of GoogleMapsPlacesV1RouteModifiers.



2677
2678
2679
# File 'lib/google/apis/places_v1/classes.rb', line 2677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avoid_ferriesBoolean Also known as: avoid_ferries?

Optional. When set to true, avoids ferries where reasonable, giving preference to routes not containing ferries. Applies only to the DRIVE and TWO_WHEELER TravelMode. Corresponds to the JSON property avoidFerries

Returns:

  • (Boolean)


2650
2651
2652
# File 'lib/google/apis/places_v1/classes.rb', line 2650

def avoid_ferries
  @avoid_ferries
end

#avoid_highwaysBoolean Also known as: avoid_highways?

Optional. When set to true, avoids highways where reasonable, giving preference to routes not containing highways. Applies only to the DRIVE and TWO_WHEELER TravelMode. Corresponds to the JSON property avoidHighways

Returns:

  • (Boolean)


2658
2659
2660
# File 'lib/google/apis/places_v1/classes.rb', line 2658

def avoid_highways
  @avoid_highways
end

#avoid_indoorBoolean Also known as: avoid_indoor?

Optional. When set to true, avoids navigating indoors where reasonable, giving preference to routes not containing indoor navigation. Applies only to the WALK TravelMode. Corresponds to the JSON property avoidIndoor

Returns:

  • (Boolean)


2666
2667
2668
# File 'lib/google/apis/places_v1/classes.rb', line 2666

def avoid_indoor
  @avoid_indoor
end

#avoid_tollsBoolean Also known as: avoid_tolls?

Optional. When set to true, avoids toll roads where reasonable, giving preference to routes not containing toll roads. Applies only to the DRIVE and TWO_WHEELER TravelMode. Corresponds to the JSON property avoidTolls

Returns:

  • (Boolean)


2674
2675
2676
# File 'lib/google/apis/places_v1/classes.rb', line 2674

def avoid_tolls
  @avoid_tolls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2682
2683
2684
2685
2686
2687
# File 'lib/google/apis/places_v1/classes.rb', line 2682

def update!(**args)
  @avoid_ferries = args[:avoid_ferries] if args.key?(:avoid_ferries)
  @avoid_highways = args[:avoid_highways] if args.key?(:avoid_highways)
  @avoid_indoor = args[:avoid_indoor] if args.key?(:avoid_indoor)
  @avoid_tolls = args[:avoid_tolls] if args.key?(:avoid_tolls)
end