Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchNearbyResponse
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchNearbyResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Response proto for Search Nearby.
Instance Attribute Summary collapse
-
#places ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Place>
A list of places that meets user's requirements like places types, number of places and specific location restriction.
-
#routing_summaries ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1RoutingSummary>
A list of routing summaries where each entry associates to the corresponding place in the same index in the
placesfield.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchNearbyResponse
constructor
A new instance of GoogleMapsPlacesV1SearchNearbyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchNearbyResponse
Returns a new instance of GoogleMapsPlacesV1SearchNearbyResponse.
2969 2970 2971 |
# File 'lib/google/apis/places_v1/classes.rb', line 2969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#places ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Place>
A list of places that meets user's requirements like places types, number of
places and specific location restriction.
Corresponds to the JSON property places
2959 2960 2961 |
# File 'lib/google/apis/places_v1/classes.rb', line 2959 def places @places end |
#routing_summaries ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1RoutingSummary>
A list of routing summaries where each entry associates to the corresponding
place in the same index in the places field. If the routing summary is not
available for one of the places, it will contain an empty entry. This list
should have as many entries as the list of places if requested.
Corresponds to the JSON property routingSummaries
2967 2968 2969 |
# File 'lib/google/apis/places_v1/classes.rb', line 2967 def routing_summaries @routing_summaries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2974 2975 2976 2977 |
# File 'lib/google/apis/places_v1/classes.rb', line 2974 def update!(**args) @places = args[:places] if args.key?(:places) @routing_summaries = args[:routing_summaries] if args.key?(:routing_summaries) end |