Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextRequestSearchAlongRouteParameters
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextRequestSearchAlongRouteParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Specifies a precalculated polyline from the Routes API defining the route to search. Searching
along a route is similar to using the locationBias or locationRestriction
request option to bias the search results. However, while the locationBias
and locationRestriction options let you specify a region to bias the search
results, this option lets you bias the results along a trip route. Results are
not guaranteed to be along the route provided, but rather are ranked within
the search area defined by the polyline and, optionally, by the locationBias
or locationRestriction based on minimal detour times from origin to
destination. The results might be along an alternate route, especially if the
provided polyline does not define an optimal route from origin to destination.
Instance Attribute Summary collapse
-
#polyline ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1Polyline
A route polyline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextRequestSearchAlongRouteParameters
constructor
A new instance of GoogleMapsPlacesV1SearchTextRequestSearchAlongRouteParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextRequestSearchAlongRouteParameters
Returns a new instance of GoogleMapsPlacesV1SearchTextRequestSearchAlongRouteParameters.
3299 3300 3301 |
# File 'lib/google/apis/places_v1/classes.rb', line 3299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#polyline ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1Polyline
A route polyline. Only supports an encoded polyline, which can be
passed as a string and includes compression with minimal lossiness. This is
the Routes API default output.
Corresponds to the JSON property polyline
3297 3298 3299 |
# File 'lib/google/apis/places_v1/classes.rb', line 3297 def polyline @polyline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3304 3305 3306 |
# File 'lib/google/apis/places_v1/classes.rb', line 3304 def update!(**args) @polyline = args[:polyline] if args.key?(:polyline) end |