Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextResponse
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Response proto for SearchText.
Instance Attribute Summary collapse
-
#contextual_contents ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContent>
Experimental: See https://developers.google.com/maps/documentation/places/web- service/experimental/places-generative for more details.
-
#next_page_token ⇒ String
A token that can be sent as
page_tokento retrieve the next page. -
#places ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Place>
A list of places that meet the user's text search criteria.
-
#routing_summaries ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1RoutingSummary>
A list of routing summaries where each entry associates to the corresponding place in the same index in the
placesfield. -
#search_uri ⇒ String
A link allows the user to search with the same text query as specified in the request on Google Maps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextResponse
constructor
A new instance of GoogleMapsPlacesV1SearchTextResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextResponse
Returns a new instance of GoogleMapsPlacesV1SearchTextResponse.
3433 3434 3435 |
# File 'lib/google/apis/places_v1/classes.rb', line 3433 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contextual_contents ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContent>
Experimental: See https://developers.google.com/maps/documentation/places/web-
service/experimental/places-generative for more details. A list of contextual
contents where each entry associates to the corresponding place in the same
index in the places field. The contents that are relevant to the text_query
in the request are preferred. If the contextual content is not available for
one of the places, it will return non-contextual content. It will be empty
only when the content is unavailable for this place. This list will have as
many entries as the list of places if requested.
Corresponds to the JSON property contextualContents
3406 3407 3408 |
# File 'lib/google/apis/places_v1/classes.rb', line 3406 def contextual_contents @contextual_contents end |
#next_page_token ⇒ String
A token that can be sent as page_token to retrieve the next page. If this
field is omitted or empty, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
3412 3413 3414 |
# File 'lib/google/apis/places_v1/classes.rb', line 3412 def next_page_token @next_page_token end |
#places ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1Place>
A list of places that meet the user's text search criteria.
Corresponds to the JSON property places
3417 3418 3419 |
# File 'lib/google/apis/places_v1/classes.rb', line 3417 def places @places end |
#routing_summaries ⇒ Array<Google::Apis::PlacesV1::GoogleMapsPlacesV1RoutingSummary>
A list of routing summaries where each entry associates to the corresponding
place in the same index in the places field. If the routing summary is not
available for one of the places, it will contain an empty entry. This list
will have as many entries as the list of places if requested.
Corresponds to the JSON property routingSummaries
3425 3426 3427 |
# File 'lib/google/apis/places_v1/classes.rb', line 3425 def routing_summaries @routing_summaries end |
#search_uri ⇒ String
A link allows the user to search with the same text query as specified in the
request on Google Maps.
Corresponds to the JSON property searchUri
3431 3432 3433 |
# File 'lib/google/apis/places_v1/classes.rb', line 3431 def search_uri @search_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3438 3439 3440 3441 3442 3443 3444 |
# File 'lib/google/apis/places_v1/classes.rb', line 3438 def update!(**args) @contextual_contents = args[:contextual_contents] if args.key?(:contextual_contents) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @places = args[:places] if args.key?(:places) @routing_summaries = args[:routing_summaries] if args.key?(:routing_summaries) @search_uri = args[:search_uri] if args.key?(:search_uri) end |