Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1SearchTextResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Response proto for SearchText.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1SearchTextResponse

Returns a new instance of GoogleMapsPlacesV1SearchTextResponse.



3356
3357
3358
# File 'lib/google/apis/places_v1/classes.rb', line 3356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextual_contentsArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1ContextualContent>

Experimental: See https://developers.google.com/maps/documentation/places/web- service/experimental/places-generative for more details. A list of contextual contents where each entry associates to the corresponding place in the same index in the places field. The contents that are relevant to the text_query in the request are preferred. If the contextual content is not available for one of the places, it will return non-contextual content. It will be empty only when the content is unavailable for this place. This list will have as many entries as the list of places if requested. Corresponds to the JSON property contextualContents



3329
3330
3331
# File 'lib/google/apis/places_v1/classes.rb', line 3329

def contextual_contents
  @contextual_contents
end

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page. If this field is omitted or empty, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3335
3336
3337
# File 'lib/google/apis/places_v1/classes.rb', line 3335

def next_page_token
  @next_page_token
end

#placesArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1Place>

A list of places that meet the user's text search criteria. Corresponds to the JSON property places



3340
3341
3342
# File 'lib/google/apis/places_v1/classes.rb', line 3340

def places
  @places
end

#routing_summariesArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1RoutingSummary>

A list of routing summaries where each entry associates to the corresponding place in the same index in the places field. If the routing summary is not available for one of the places, it will contain an empty entry. This list will have as many entries as the list of places if requested. Corresponds to the JSON property routingSummaries



3348
3349
3350
# File 'lib/google/apis/places_v1/classes.rb', line 3348

def routing_summaries
  @routing_summaries
end

#search_uriString

A link allows the user to search with the same text query as specified in the request on Google Maps. Corresponds to the JSON property searchUri

Returns:

  • (String)


3354
3355
3356
# File 'lib/google/apis/places_v1/classes.rb', line 3354

def search_uri
  @search_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3361
3362
3363
3364
3365
3366
3367
# File 'lib/google/apis/places_v1/classes.rb', line 3361

def update!(**args)
  @contextual_contents = args[:contextual_contents] if args.key?(:contextual_contents)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @places = args[:places] if args.key?(:places)
  @routing_summaries = args[:routing_summaries] if args.key?(:routing_summaries)
  @search_uri = args[:search_uri] if args.key?(:search_uri)
end