Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitAgency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Represents a transit agency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1TransitAgency

Returns a new instance of GoogleMapsPlacesV1TransitAgency.



3387
3388
3389
# File 'lib/google/apis/places_v1/classes.rb', line 3387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property displayName



3365
3366
3367
# File 'lib/google/apis/places_v1/classes.rb', line 3365

def display_name
  @display_name
end

#fare_urlString

The URL of the agency's fare details page. Corresponds to the JSON property fareUrl

Returns:

  • (String)


3370
3371
3372
# File 'lib/google/apis/places_v1/classes.rb', line 3370

def fare_url
  @fare_url
end

#iconGoogle::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon

Icon for a transit line, vehicle, or agency. Corresponds to the JSON property icon



3375
3376
3377
# File 'lib/google/apis/places_v1/classes.rb', line 3375

def icon
  @icon
end

#linesArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitLine>

The transit lines that are served by this agency. Corresponds to the JSON property lines



3380
3381
3382
# File 'lib/google/apis/places_v1/classes.rb', line 3380

def lines
  @lines
end

#urlString

The URL of the agency's homepage. Corresponds to the JSON property url

Returns:

  • (String)


3385
3386
3387
# File 'lib/google/apis/places_v1/classes.rb', line 3385

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3392
3393
3394
3395
3396
3397
3398
# File 'lib/google/apis/places_v1/classes.rb', line 3392

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @fare_url = args[:fare_url] if args.key?(:fare_url)
  @icon = args[:icon] if args.key?(:icon)
  @lines = args[:lines] if args.key?(:lines)
  @url = args[:url] if args.key?(:url)
end