Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitAgency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Represents a transit agency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1TransitAgency

Returns a new instance of GoogleMapsPlacesV1TransitAgency.



3399
3400
3401
# File 'lib/google/apis/places_v1/classes.rb', line 3399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property displayName



3377
3378
3379
# File 'lib/google/apis/places_v1/classes.rb', line 3377

def display_name
  @display_name
end

#fare_urlString

The URL of the agency's fare details page. Corresponds to the JSON property fareUrl

Returns:

  • (String)


3382
3383
3384
# File 'lib/google/apis/places_v1/classes.rb', line 3382

def fare_url
  @fare_url
end

#iconGoogle::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon

Icon for a transit line, vehicle, or agency. Corresponds to the JSON property icon



3387
3388
3389
# File 'lib/google/apis/places_v1/classes.rb', line 3387

def icon
  @icon
end

#linesArray<Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitLine>

The transit lines that are served by this agency. Corresponds to the JSON property lines



3392
3393
3394
# File 'lib/google/apis/places_v1/classes.rb', line 3392

def lines
  @lines
end

#urlString

The URL of the agency's homepage. Corresponds to the JSON property url

Returns:

  • (String)


3397
3398
3399
# File 'lib/google/apis/places_v1/classes.rb', line 3397

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3404
3405
3406
3407
3408
3409
3410
# File 'lib/google/apis/places_v1/classes.rb', line 3404

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @fare_url = args[:fare_url] if args.key?(:fare_url)
  @icon = args[:icon] if args.key?(:icon)
  @lines = args[:lines] if args.key?(:lines)
  @url = args[:url] if args.key?(:url)
end