Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Icon for a transit line, vehicle, or agency.
Instance Attribute Summary collapse
-
#name_included ⇒ Boolean
(also: #name_included?)
Whether the name is contained in the icon and there is no need to display it next to the icon.
-
#url ⇒ String
The URL of the icon.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1TransitIcon
constructor
A new instance of GoogleMapsPlacesV1TransitIcon.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1TransitIcon
Returns a new instance of GoogleMapsPlacesV1TransitIcon.
3429 3430 3431 |
# File 'lib/google/apis/places_v1/classes.rb', line 3429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name_included ⇒ Boolean Also known as: name_included?
Whether the name is contained in the icon and there is no need to display it
next to the icon.
Corresponds to the JSON property nameIncluded
3421 3422 3423 |
# File 'lib/google/apis/places_v1/classes.rb', line 3421 def name_included @name_included end |
#url ⇒ String
The URL of the icon.
Corresponds to the JSON property url
3427 3428 3429 |
# File 'lib/google/apis/places_v1/classes.rb', line 3427 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3434 3435 3436 3437 |
# File 'lib/google/apis/places_v1/classes.rb', line 3434 def update!(**args) @name_included = args[:name_included] if args.key?(:name_included) @url = args[:url] if args.key?(:url) end |