Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitLine
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitLine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Represents a single transit line.
Instance Attribute Summary collapse
-
#background_color ⇒ String
The background color of the labels for this transit line in #RRGGBB hex format, e.g.
-
#display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#icon ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon
Icon for a transit line, vehicle, or agency.
-
#id ⇒ String
The id of the transit line that can be used to uniquely identify the line among other transit lines in the same transit station.
-
#short_display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#text_color ⇒ String
The text color of labels for this transit line in #RRGGBB hex format, e.g.
-
#url ⇒ String
The URL of a webpage with details about this line.
-
#vehicle_icon ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon
Icon for a transit line, vehicle, or agency.
-
#vehicle_type ⇒ String
The type of vehicle using this line.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1TransitLine
constructor
A new instance of GoogleMapsPlacesV1TransitLine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1TransitLine
Returns a new instance of GoogleMapsPlacesV1TransitLine.
3482 3483 3484 |
# File 'lib/google/apis/places_v1/classes.rb', line 3482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_color ⇒ String
The background color of the labels for this transit line in #RRGGBB hex format,
e.g. #909CE1. This color can also be used for drawing shapes for this transit
line.
Corresponds to the JSON property backgroundColor
3437 3438 3439 |
# File 'lib/google/apis/places_v1/classes.rb', line 3437 def background_color @background_color end |
#display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property displayName
3442 3443 3444 |
# File 'lib/google/apis/places_v1/classes.rb', line 3442 def display_name @display_name end |
#icon ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon
Icon for a transit line, vehicle, or agency.
Corresponds to the JSON property icon
3447 3448 3449 |
# File 'lib/google/apis/places_v1/classes.rb', line 3447 def icon @icon end |
#id ⇒ String
The id of the transit line that can be used to uniquely identify the line
among other transit lines in the same transit station. This identifier is not
guaranteed to be stable across different responses.
Corresponds to the JSON property id
3454 3455 3456 |
# File 'lib/google/apis/places_v1/classes.rb', line 3454 def id @id end |
#short_display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property shortDisplayName
3459 3460 3461 |
# File 'lib/google/apis/places_v1/classes.rb', line 3459 def short_display_name @short_display_name end |
#text_color ⇒ String
The text color of labels for this transit line in #RRGGBB hex format, e.g. #
909CE1.
Corresponds to the JSON property textColor
3465 3466 3467 |
# File 'lib/google/apis/places_v1/classes.rb', line 3465 def text_color @text_color end |
#url ⇒ String
The URL of a webpage with details about this line.
Corresponds to the JSON property url
3470 3471 3472 |
# File 'lib/google/apis/places_v1/classes.rb', line 3470 def url @url end |
#vehicle_icon ⇒ Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitIcon
Icon for a transit line, vehicle, or agency.
Corresponds to the JSON property vehicleIcon
3475 3476 3477 |
# File 'lib/google/apis/places_v1/classes.rb', line 3475 def vehicle_icon @vehicle_icon end |
#vehicle_type ⇒ String
The type of vehicle using this line.
Corresponds to the JSON property vehicleType
3480 3481 3482 |
# File 'lib/google/apis/places_v1/classes.rb', line 3480 def vehicle_type @vehicle_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 |
# File 'lib/google/apis/places_v1/classes.rb', line 3487 def update!(**args) @background_color = args[:background_color] if args.key?(:background_color) @display_name = args[:display_name] if args.key?(:display_name) @icon = args[:icon] if args.key?(:icon) @id = args[:id] if args.key?(:id) @short_display_name = args[:short_display_name] if args.key?(:short_display_name) @text_color = args[:text_color] if args.key?(:text_color) @url = args[:url] if args.key?(:url) @vehicle_icon = args[:vehicle_icon] if args.key?(:vehicle_icon) @vehicle_type = args[:vehicle_type] if args.key?(:vehicle_type) end |