Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStop
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStop
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
Represents a transit stop within a station. This is a specific location where
passengers board and alight transit vehicles, such as a platform or bus bay.
This is distinct from a Departure, which is an event of a vehicle leaving a
stop at a specific time.
Instance Attribute Summary collapse
-
#display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#id ⇒ String
The id of the transit stop that can be used to uniquely identify the stop among other transit stops in the same transit station.
-
#location ⇒ Google::Apis::PlacesV1::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
-
#platform_code ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#signage_text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#stop_code ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
-
#wheelchair_accessible_entrance ⇒ Boolean
(also: #wheelchair_accessible_entrance?)
Wheelchair accessibility of this stop.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsPlacesV1TransitStop
constructor
A new instance of GoogleMapsPlacesV1TransitStop.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsPlacesV1TransitStop
Returns a new instance of GoogleMapsPlacesV1TransitStop.
3670 3671 3672 |
# File 'lib/google/apis/places_v1/classes.rb', line 3670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property displayName
3630 3631 3632 |
# File 'lib/google/apis/places_v1/classes.rb', line 3630 def display_name @display_name end |
#id ⇒ String
The id of the transit stop that can be used to uniquely identify the stop
among other transit stops in the same transit station. This identifier is not
guaranteed to be stable across different responses.
Corresponds to the JSON property id
3637 3638 3639 |
# File 'lib/google/apis/places_v1/classes.rb', line 3637 def id @id end |
#location ⇒ Google::Apis::PlacesV1::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property location
3645 3646 3647 |
# File 'lib/google/apis/places_v1/classes.rb', line 3645 def location @location end |
#platform_code ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property platformCode
3650 3651 3652 |
# File 'lib/google/apis/places_v1/classes.rb', line 3650 def platform_code @platform_code end |
#signage_text ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property signageText
3655 3656 3657 |
# File 'lib/google/apis/places_v1/classes.rb', line 3655 def signage_text @signage_text end |
#stop_code ⇒ Google::Apis::PlacesV1::GoogleTypeLocalizedText
Localized variant of a text in a particular language.
Corresponds to the JSON property stopCode
3660 3661 3662 |
# File 'lib/google/apis/places_v1/classes.rb', line 3660 def stop_code @stop_code end |
#wheelchair_accessible_entrance ⇒ Boolean Also known as: wheelchair_accessible_entrance?
Wheelchair accessibility of this stop. This field indicates whether there is
an accessible path from outside the station to the stop. It does not indicate
whether it is possible to board a vehicle from the stop.
Corresponds to the JSON property wheelchairAccessibleEntrance
3667 3668 3669 |
# File 'lib/google/apis/places_v1/classes.rb', line 3667 def wheelchair_accessible_entrance @wheelchair_accessible_entrance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3675 3676 3677 3678 3679 3680 3681 3682 3683 |
# File 'lib/google/apis/places_v1/classes.rb', line 3675 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @location = args[:location] if args.key?(:location) @platform_code = args[:platform_code] if args.key?(:platform_code) @signage_text = args[:signage_text] if args.key?(:signage_text) @stop_code = args[:stop_code] if args.key?(:stop_code) @wheelchair_accessible_entrance = args[:wheelchair_accessible_entrance] if args.key?(:wheelchair_accessible_entrance) end |