Class: Google::Apis::PlacesV1::GoogleMapsPlacesV1TransitStop

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb

Overview

Represents a transit stop within a station. This is a specific location where passengers board and alight transit vehicles, such as a platform or bus bay. This is distinct from a Departure, which is an event of a vehicle leaving a stop at a specific time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsPlacesV1TransitStop

Returns a new instance of GoogleMapsPlacesV1TransitStop.



3581
3582
3583
# File 'lib/google/apis/places_v1/classes.rb', line 3581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property displayName



3541
3542
3543
# File 'lib/google/apis/places_v1/classes.rb', line 3541

def display_name
  @display_name
end

#idString

The id of the transit stop that can be used to uniquely identify the stop among other transit stops in the same transit station. This identifier is not guaranteed to be stable across different responses. Corresponds to the JSON property id

Returns:

  • (String)


3548
3549
3550
# File 'lib/google/apis/places_v1/classes.rb', line 3548

def id
  @id
end

#locationGoogle::Apis::PlacesV1::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property location



3556
3557
3558
# File 'lib/google/apis/places_v1/classes.rb', line 3556

def location
  @location
end

#platform_codeGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property platformCode



3561
3562
3563
# File 'lib/google/apis/places_v1/classes.rb', line 3561

def platform_code
  @platform_code
end

#signage_textGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property signageText



3566
3567
3568
# File 'lib/google/apis/places_v1/classes.rb', line 3566

def signage_text
  @signage_text
end

#stop_codeGoogle::Apis::PlacesV1::GoogleTypeLocalizedText

Localized variant of a text in a particular language. Corresponds to the JSON property stopCode



3571
3572
3573
# File 'lib/google/apis/places_v1/classes.rb', line 3571

def stop_code
  @stop_code
end

#wheelchair_accessible_entranceBoolean Also known as: wheelchair_accessible_entrance?

Wheelchair accessibility of this stop. This field indicates whether there is an accessible path from outside the station to the stop. It does not indicate whether it is possible to board a vehicle from the stop. Corresponds to the JSON property wheelchairAccessibleEntrance

Returns:

  • (Boolean)


3578
3579
3580
# File 'lib/google/apis/places_v1/classes.rb', line 3578

def wheelchair_accessible_entrance
  @wheelchair_accessible_entrance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3586
3587
3588
3589
3590
3591
3592
3593
3594
# File 'lib/google/apis/places_v1/classes.rb', line 3586

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @location = args[:location] if args.key?(:location)
  @platform_code = args[:platform_code] if args.key?(:platform_code)
  @signage_text = args[:signage_text] if args.key?(:signage_text)
  @stop_code = args[:stop_code] if args.key?(:stop_code)
  @wheelchair_accessible_entrance = args[:wheelchair_accessible_entrance] if args.key?(:wheelchair_accessible_entrance)
end