Class: Google::Apis::PlacesV1::GoogleTypeLatLng
- Inherits:
-
Object
- Object
- Google::Apis::PlacesV1::GoogleTypeLatLng
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/places_v1/classes.rb,
lib/google/apis/places_v1/representations.rb,
lib/google/apis/places_v1/representations.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ Float
The latitude in degrees.
-
#longitude ⇒ Float
The longitude in degrees.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeLatLng
constructor
A new instance of GoogleTypeLatLng.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeLatLng
Returns a new instance of GoogleTypeLatLng.
3655 3656 3657 |
# File 'lib/google/apis/places_v1/classes.rb', line 3655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latitude ⇒ Float
The latitude in degrees. It must be in the range [-90.0, +90.0].
Corresponds to the JSON property latitude
3648 3649 3650 |
# File 'lib/google/apis/places_v1/classes.rb', line 3648 def latitude @latitude end |
#longitude ⇒ Float
The longitude in degrees. It must be in the range [-180.0, +180.0].
Corresponds to the JSON property longitude
3653 3654 3655 |
# File 'lib/google/apis/places_v1/classes.rb', line 3653 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3660 3661 3662 3663 |
# File 'lib/google/apis/places_v1/classes.rb', line 3660 def update!(**args) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |